#
# Generated by TigerShark.tools.convertPyX12 on 2012-07-10 16:30:03.615673
#
from tigershark.X12.parse import Message, Loop, Segment, Composite, Element, Properties
parsed_837_1000A = Loop( u'1000A', Properties(looptype='',repeat=u'1',pos=u'020',req_sit=u'R',desc=u'Submitter Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'020',desc=u'Submitter Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'41'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'46'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PER', Properties(syntax=u'P0304 P0506 P0708',req_sit=u'R',repeat=u'2',pos=u'045',desc=u'Submitter EDI Contact Information'),
  Element( u'PER01', Properties(desc=u'Contact Function Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'IC'] ) ),
  Element( u'PER02', Properties(desc=u'Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=2,
    codes=[] ) ),
  Element( u'PER03', Properties(desc=u'Communication Number Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'ED', u'EM', u'FX', u'TE'] ) ),
  Element( u'PER04', Properties(desc=u'Communication Number', req_sit=u'R', data_type=(u'AN',u'1',u'256'), position=4,
    codes=[] ) ),
  Element( u'PER05', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'ED', u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER06', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=6,
    codes=[] ) ),
  Element( u'PER07', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'ED', u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER08', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=8,
    codes=[] ) ),
  Element( u'PER09', Properties(desc=u'Contact Inquiry Reference', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=9,
    codes=[] ) ),
),
)
parsed_837_1000B = Loop( u'1000B', Properties(looptype='',repeat=u'1',pos=u'020',req_sit=u'R',desc=u'Receiver Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'020',desc=u'Receiver Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'40'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'46'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
)
parsed_837_HEADER = Loop( u'HEADER', Properties(looptype=u'wrapper',repeat=u'1',pos=u'010',req_sit=u'R',desc=u'Table 1 - Header'),
Segment( u'BHT', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'010',desc=u'Beginning of Hierarchical Transaction'),
  Element( u'BHT01', Properties(desc=u'Hierarchical Structure Code', req_sit=u'R', data_type=(u'ID',u'4',u'4'), position=1,
    codes=[u'0019'] ) ),
  Element( u'BHT02', Properties(desc=u'Transaction Set Purpose Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'00', u'18'] ) ),
  Element( u'BHT03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'BHT04', Properties(desc=u'Date', req_sit=u'R', data_type=(u'DT',u'8',u'8'), position=4,
    codes=[] ) ),
  Element( u'BHT05', Properties(desc=u'Time', req_sit=u'R', data_type=(u'TM',u'4',u'8'), position=5,
    codes=[] ) ),
  Element( u'BHT06', Properties(desc=u'Transaction Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=6,
    codes=[u'CH', u'RP'] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Transmission Type Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'87'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'004010X098DA1', u'004010X098A1'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
parsed_837_1000A,
parsed_837_1000B,
)
parsed_837_2010AA = Loop( u'2010AA', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'R',desc=u'Billing Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Billing Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'85'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'025',desc=u'Billing Provider Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Billing Provider City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'8',pos=u'035',desc=u'Billing Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'1J', u'B3', u'BQ', u'EI', u'FH', u'G2', u'G5', u'LU', u'SY', u'U3', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'8',pos=u'035',desc=u'Credit/Debit Card Billing Information'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'06', u'8U', u'EM', u'IJ', u'LU', u'RB', u'ST', u'TT'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'PER', Properties(syntax=u'P0304 P0506 P0708',req_sit=u'S',repeat=u'2',pos=u'040',desc=u'Billing Provider Contact Information'),
  Element( u'PER01', Properties(desc=u'Contact Function Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'IC'] ) ),
  Element( u'PER02', Properties(desc=u'Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=2,
    codes=[] ) ),
  Element( u'PER03', Properties(desc=u'Communication Number Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'EM', u'FX', u'TE'] ) ),
  Element( u'PER04', Properties(desc=u'Communication Number', req_sit=u'R', data_type=(u'AN',u'1',u'256'), position=4,
    codes=[] ) ),
  Element( u'PER05', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER06', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=6,
    codes=[] ) ),
  Element( u'PER07', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER08', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=8,
    codes=[] ) ),
  Element( u'PER09', Properties(desc=u'Contact Inquiry Reference', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=9,
    codes=[] ) ),
),
)
parsed_837_2010AB = Loop( u'2010AB', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'S',desc=u'Pay-To Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Pay-To Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'87'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'025',desc=u'Pay-To Provider Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Pay-To Provider City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'035',desc=u'Pay-To Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'1J', u'B3', u'BQ', u'EI', u'FH', u'G2', u'G5', u'LU', u'SY', u'U3', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2010BA = Loop( u'2010BA', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'R',desc=u'Subscriber Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Subscriber Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'IL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI', u'ZZ'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'025',desc=u'Subscriber Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'S',repeat=u'1',pos=u'030',desc=u'Subscriber City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'DMG', Properties(syntax=u'P0102',req_sit=u'S',repeat=u'1',pos=u'032',desc=u'Subscriber Demographic Information'),
  Element( u'DMG01', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'DMG02', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=2,
    codes=[] ) ),
  Element( u'DMG03', Properties(desc=u'Gender Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'F', u'M', u'U'] ) ),
  Element( u'DMG04', Properties(desc=u'Marital Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'DMG05', Properties(desc=u'Race or Ethnicity Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'DMG06', Properties(desc=u'Citizenship Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Element( u'DMG07', Properties(desc=u'Country Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
  Element( u'DMG08', Properties(desc=u'Basis of Verification Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'DMG09', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=9,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'4',pos=u'035',desc=u'Subscriber Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'035',desc=u'Property and Casualty Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'Y4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2010BB = Loop( u'2010BB', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'R',desc=u'Destination Payer'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Destination Payer Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'PR'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'PI', u'XV'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'025',desc=u'Destination Payer Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'S',repeat=u'1',pos=u'030',desc=u'Destination Payer City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'3',pos=u'035',desc=u'Destination Payer Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'2U', u'FY', u'NF', u'TJ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2010BC = Loop( u'2010BC', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'S',desc=u'Responsible Party Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Responsible Party Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QD'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'025',desc=u'Responsible Party Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Responsible Party City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
)
parsed_837_2010BD = Loop( u'2010BD', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'S',desc=u'Credit/Debit Card Holder Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Credit/Debit Card Holder Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'AO'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'035',desc=u'Credit/Debit Card Information'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'AB', u'BB'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2305 = Loop( u'2305', Properties(looptype='',repeat=u'6',pos=u'242',req_sit=u'S',desc=u'Home Health Care Plan Information'),
Segment( u'CR7', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'242',desc=u'Home Health Care Plan Information'),
  Element( u'CR701', Properties(desc=u'Discipline Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'AI', u'MS', u'OT', u'PT', u'SN', u'ST'] ) ),
  Element( u'CR702', Properties(desc=u'Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=2,
    codes=[] ) ),
  Element( u'CR703', Properties(desc=u'Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=3,
    codes=[] ) ),
),
Segment( u'HSD', Properties(syntax=u'P0102 C0605',req_sit=u'S',repeat=u'3',pos=u'243',desc=u'Health Care Services Delivery'),
  Element( u'HSD01', Properties(desc=u'Quantity Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'VS'] ) ),
  Element( u'HSD02', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'HSD03', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'DA', u'MO', u'Q1', u'WK'] ) ),
  Element( u'HSD04', Properties(desc=u'Sample Selection Modulus', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=4,
    codes=[] ) ),
  Element( u'HSD05', Properties(desc=u'Time Period Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'7', u'35'] ) ),
  Element( u'HSD06', Properties(desc=u'Number of Periods', req_sit=u'S', data_type=(u'N0',u'1',u'3'), position=6,
    codes=[] ) ),
  Element( u'HSD07', Properties(desc=u'Ship/Delivery or Calendar Pattern Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=7,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'J', u'K', u'L', u'N', u'O', u'S', u'W', u'SA', u'SB', u'SC', u'SD', u'SG', u'SL', u'SP', u'SX', u'SY', u'SZ'] ) ),
  Element( u'HSD08', Properties(desc=u'Ship/Delivery Pattern Time Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'D', u'E', u'F'] ) ),
),
)
parsed_837_2310A = Loop( u'2310A', Properties(looptype='',repeat=u'2',pos=u'250',req_sit=u'S',desc=u'Referring Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Referring Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DN', u'P3'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Referring Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'RF'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes=u'PRV05',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Referring Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310B = Loop( u'2310B', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Rendering Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Rendering Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'82'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Rendering Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'PE'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes=u'PRV05',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Rendering Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310C = Loop( u'2310C', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Purchased Service Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Purchased Service Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QB'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Purchased Service Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'U3', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310D = Loop( u'2310D', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Service Facility Location'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Service Facility Location'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'77', u'FA', u'LI', u'TL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'265',desc=u'Service Facility Location Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'R',repeat=u'1',pos=u'270',desc=u'Service Facility Location City/State/ZIP'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Service Facility Location Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'G2', u'LU', u'N5', u'TJ', u'X4', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310E = Loop( u'2310E', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Supervising Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Supervising Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DQ'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Supervising Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330A = Loop( u'2330A', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'R',desc=u'Other Subscriber Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Subscriber Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'IL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI', u'ZZ'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'332',desc=u'Other Subscriber Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'S',repeat=u'1',pos=u'340',desc=u'Other Subscriber City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'S', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'S', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'3',pos=u'355',desc=u'Other Subscriber Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330B = Loop( u'2330B', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'R',desc=u'Other Payer Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'PR'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'PI', u'XV'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PER', Properties(syntax=u'P0304 P0506 P0708',req_sit=u'S',repeat=u'2',pos=u'345',desc=u'Other Payer Contact Information'),
  Element( u'PER01', Properties(desc=u'Contact Function Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'IC'] ) ),
  Element( u'PER02', Properties(desc=u'Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=2,
    codes=[] ) ),
  Element( u'PER03', Properties(desc=u'Communication Number Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'ED', u'EM', u'FX', u'TE'] ) ),
  Element( u'PER04', Properties(desc=u'Communication Number', req_sit=u'R', data_type=(u'AN',u'1',u'256'), position=4,
    codes=[] ) ),
  Element( u'PER05', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'ED', u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER06', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=6,
    codes=[] ) ),
  Element( u'PER07', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'ED', u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER08', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=8,
    codes=[] ) ),
  Element( u'PER09', Properties(desc=u'Contact Inquiry Reference', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=9,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'345',desc=u'Claim Adjudication Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'573'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'355',desc=u'Other Payer Secondary Identifier'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'2U', u'F8', u'FY', u'NF', u'TJ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'355',desc=u'Other Payer Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'355',desc=u'Other Payer Claim Adjustment Indicator'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'T4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'Y'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330C = Loop( u'2330C', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Patient Information'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Patient Information'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QC'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'3',pos=u'355',desc=u'Other Payer Patient Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330D = Loop( u'2330D', Properties(looptype='',repeat=u'2',pos=u'325',req_sit=u'S',desc=u'Other Payer Referring Provider'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Referring Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DN', u'P3'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Referring Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1B', u'1C', u'1D', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330E = Loop( u'2330E', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Rendering Provider'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Rendering Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'82'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Rendering Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1B', u'1C', u'1D', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330F = Loop( u'2330F', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Purchased Service Provider'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Purchased Service Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QB'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Purchased Service Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330G = Loop( u'2330G', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Service Facility Location'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Service Facility Location'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'77', u'FA', u'LI', u'TL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Service Facility Location Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330H = Loop( u'2330H', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Supervising Provider'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Supervising Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DQ'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Supervising Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1B', u'1C', u'1D', u'EI', u'G2', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2320 = Loop( u'2320', Properties(looptype='',repeat=u'10',pos=u'290',req_sit=u'S',desc=u'Other Subscriber Information'),
Segment( u'SBR', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'290',desc=u'Other Subscriber Information'),
  Element( u'SBR01', Properties(desc=u'Payer Responsibility Sequence Number Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'P', u'S', u'T'] ) ),
  Element( u'SBR02', Properties(desc=u'Individual Relationship Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'01', u'04', u'05', u'07', u'10', u'15', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'29', u'32', u'33', u'36', u'39', u'40', u'41', u'43', u'53', u'G8'] ) ),
  Element( u'SBR03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'SBR04', Properties(desc=u'Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=4,
    codes=[] ) ),
  Element( u'SBR05', Properties(desc=u'Insurance Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=5,
    codes=[u'AP', u'C1', u'CP', u'GP', u'HM', u'IP', u'LD', u'LT', u'MB', u'MC', u'MI', u'MP', u'OT', u'PP', u'SP'] ) ),
  Element( u'SBR06', Properties(desc=u'Coordination of Benefits Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[] ) ),
  Element( u'SBR07', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[] ) ),
  Element( u'SBR08', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[] ) ),
  Element( u'SBR09', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[u'09', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'AM', u'BL', u'CH', u'CI', u'DS', u'HM', u'LI', u'LM', u'MB', u'MC', u'OF', u'TV', u'VA', u'WC', u'ZZ'] ) ),
),
Segment( u'CAS', Properties(syntax=u'L050607 C0605 C0705 L080910 C0908 C1008 L111213 C1211 C1311 L141516 C1514 C1614 L171819 C1817 C1917',req_sit=u'S',repeat=u'5',pos=u'295',desc=u'Claim Level Adjustments'),
  Element( u'CAS01', Properties(desc=u'Claim Adjustment Group Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[u'CO', u'CR', u'OA', u'PI', u'PR'] ) ),
  Element( u'CAS02', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'5'), position=2,
    codes=[] ) ),
  Element( u'CAS03', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'CAS04', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'CAS05', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=5,
    codes=[] ) ),
  Element( u'CAS06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'CAS07', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CAS08', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=8,
    codes=[] ) ),
  Element( u'CAS09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'CAS10', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CAS11', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=11,
    codes=[] ) ),
  Element( u'CAS12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'CAS13', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=13,
    codes=[] ) ),
  Element( u'CAS14', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=14,
    codes=[] ) ),
  Element( u'CAS15', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=15,
    codes=[] ) ),
  Element( u'CAS16', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CAS17', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=17,
    codes=[] ) ),
  Element( u'CAS18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'CAS19', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=19,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Payer Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'D'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Approved Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AAE'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Allowed Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'B6'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Patient Responsibility Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F2'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Covered Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AU'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Discount Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Per Day Limit Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'DY'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Patient Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F5'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Tax Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'T'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Claim Before Taxes Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'T2'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'DMG', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'305',desc=u'Subscriber Demographic Information'),
  Element( u'DMG01', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'DMG02', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=2,
    codes=[] ) ),
  Element( u'DMG03', Properties(desc=u'Gender Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'F', u'M', u'U'] ) ),
  Element( u'DMG04', Properties(desc=u'Marital Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'DMG05', Properties(desc=u'Race or Ethnicity Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'DMG06', Properties(desc=u'Citizenship Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Element( u'DMG07', Properties(desc=u'Country Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
  Element( u'DMG08', Properties(desc=u'Basis of Verification Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'DMG09', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=9,
    codes=[] ) ),
),
Segment( u'OI', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'310',desc=u'Other Insurance Coverage Information'),
  Element( u'OI01', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[] ) ),
  Element( u'OI02', Properties(desc=u'Claim Submission Reason Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'OI03', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'N', u'Y'] ) ),
  Element( u'OI04', Properties(desc=u'Patient Signature Source Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'B', u'C', u'M', u'P', u'S'] ) ),
  Element( u'OI05', Properties(desc=u'Provider Agreement Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'OI06', Properties(desc=u'Release of Information Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'A', u'I', u'M', u'N', u'O', u'Y'] ) ),
),
Segment( u'MOA', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'320',desc=u'Medicare Outpatient Adjudication Information'),
  Element( u'MOA01', Properties(desc=u'Percentage as Decimal', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=1,
    codes=[] ) ),
  Element( u'MOA02', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'MOA03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'MOA04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'MOA05', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=5,
    codes=[] ) ),
  Element( u'MOA06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'MOA07', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=7,
    codes=[] ) ),
  Element( u'MOA08', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'MOA09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
),
parsed_837_2330A,
parsed_837_2330B,
parsed_837_2330C,
parsed_837_2330D,
parsed_837_2330E,
parsed_837_2330F,
parsed_837_2330G,
parsed_837_2330H,
)
parsed_837_2410 = Loop( u'2410', Properties(looptype='',repeat=u'25',pos=u'494',req_sit=u'S',desc=u'Drug Identification'),
Segment( u'LIN', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'494',desc=u'Drug Identification'),
  Element( u'LIN01', Properties(desc=u'Assigned Identification', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=1,
    codes=[] ) ),
  Element( u'LIN02', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'N4'] ) ),
  Element( u'LIN03', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=3,
    codes=[] ) ),
  Element( u'LIN04', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[u'N4'] ) ),
  Element( u'LIN05', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=5,
    codes=[] ) ),
  Element( u'LIN06', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
    codes=[u'N4'] ) ),
  Element( u'LIN07', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=7,
    codes=[] ) ),
  Element( u'LIN08', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[u'N4'] ) ),
  Element( u'LIN09', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=9,
    codes=[] ) ),
  Element( u'LIN10', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[u'N4'] ) ),
  Element( u'LIN11', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=11,
    codes=[] ) ),
  Element( u'LIN12', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
    codes=[u'N4'] ) ),
  Element( u'LIN13', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=13,
    codes=[] ) ),
  Element( u'LIN14', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=14,
    codes=[u'N4'] ) ),
  Element( u'LIN15', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=15,
    codes=[] ) ),
  Element( u'LIN16', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=16,
    codes=[u'N4'] ) ),
  Element( u'LIN17', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=17,
    codes=[] ) ),
  Element( u'LIN18', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=18,
    codes=[u'N4'] ) ),
  Element( u'LIN19', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=19,
    codes=[] ) ),
  Element( u'LIN20', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=20,
    codes=[u'N4'] ) ),
  Element( u'LIN21', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=21,
    codes=[] ) ),
  Element( u'LIN22', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=22,
    codes=[u'N4'] ) ),
  Element( u'LIN23', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=23,
    codes=[] ) ),
  Element( u'LIN24', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=24,
    codes=[u'N4'] ) ),
  Element( u'LIN25', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=25,
    codes=[] ) ),
  Element( u'LIN26', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=26,
    codes=[u'N4'] ) ),
  Element( u'LIN27', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=27,
    codes=[] ) ),
  Element( u'LIN28', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=28,
    codes=[u'N4'] ) ),
  Element( u'LIN29', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=29,
    codes=[] ) ),
  Element( u'LIN30', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=30,
    codes=[u'N4'] ) ),
  Element( u'LIN31', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=31,
    codes=[] ) ),
),
Segment( u'CTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'495',desc=u'Drug Pricing'),
  Element( u'CTP01', Properties(desc=u'Class of Trade Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[] ) ),
  Element( u'CTP02', Properties(desc=u'Price Identifier Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=2,
    codes=[] ) ),
  Element( u'CTP03', Properties(desc=u'Unit Price', req_sit=u'R', data_type=(u'R',u'1',u'17'), position=3,
    codes=[] ) ),
  Element( u'CTP04', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'R',refdes='',seq=u'05',desc=u'Unit or Basis of Measurement'),
    Element( u'CTP05-01', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'F2', u'GR', u'ML', u'UN'] ) ),
    Element( u'CTP05-02', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=1,
      codes=[] ) ),
    Element( u'CTP05-03', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=2,
      codes=[] ) ),
    Element( u'CTP05-04', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'CTP05-05', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=4,
      codes=[] ) ),
    Element( u'CTP05-06', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=5,
      codes=[] ) ),
    Element( u'CTP05-07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
      codes=[] ) ),
    Element( u'CTP05-08', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
      codes=[] ) ),
    Element( u'CTP05-09', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=8,
      codes=[] ) ),
    Element( u'CTP05-10', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
      codes=[] ) ),
    Element( u'CTP05-11', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=10,
      codes=[] ) ),
    Element( u'CTP05-12', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=11,
      codes=[] ) ),
    Element( u'CTP05-13', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
      codes=[] ) ),
    Element( u'CTP05-14', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=13,
      codes=[] ) ),
    Element( u'CTP05-15', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=14,
      codes=[] ) ),
  ),
  Element( u'CTP06', Properties(desc=u'Price Multiplier Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
  Element( u'CTP07', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'CTP08', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'CTP09', Properties(desc=u'Basis of Unit Price Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[] ) ),
  Element( u'CTP10', Properties(desc=u'Condition Value', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=10,
    codes=[] ) ),
  Element( u'CTP11', Properties(desc=u'Multiple Price Quantity', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'496',desc=u'Prescription Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'XZ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420A = Loop( u'2420A', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Rendering Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Rendering Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'82'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Rendering Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'PE'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes=u'PRV05',seq=u'5',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Rendering Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420B = Loop( u'2420B', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Purchased Service Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Purchased Service Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QB'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Purchased Service Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'U3', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420C = Loop( u'2420C', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Service Facility Location'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Service Facility Location'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'77', u'FA', u'LI', u'TL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'514',desc=u'Service Facility Location Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'R',repeat=u'1',pos=u'520',desc=u'Service Facility Location City/State/ZIP'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Service Facility Location Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'G2', u'LU', u'N5', u'TJ', u'X4', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420D = Loop( u'2420D', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Supervising Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Supervising Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DQ'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Supervising Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420E = Loop( u'2420E', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Ordering Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Ordering Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DK'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'514',desc=u'Ordering Provider Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'S',repeat=u'1',pos=u'520',desc=u'Ordering Provider City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Ordering Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'PER', Properties(syntax=u'P0304 P0506 P0708',req_sit=u'S',repeat=u'1',pos=u'530',desc=u'Ordering Provider Contact Information'),
  Element( u'PER01', Properties(desc=u'Contact Function Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'IC'] ) ),
  Element( u'PER02', Properties(desc=u'Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=2,
    codes=[] ) ),
  Element( u'PER03', Properties(desc=u'Communication Number Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'EM', u'FX', u'TE'] ) ),
  Element( u'PER04', Properties(desc=u'Communication Number', req_sit=u'R', data_type=(u'AN',u'1',u'256'), position=4,
    codes=[] ) ),
  Element( u'PER05', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER06', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=6,
    codes=[] ) ),
  Element( u'PER07', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER08', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=8,
    codes=[] ) ),
  Element( u'PER09', Properties(desc=u'Contact Inquiry Reference', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=9,
    codes=[] ) ),
),
)
parsed_837_2420F = Loop( u'2420F', Properties(looptype='',repeat=u'2',pos=u'500',req_sit=u'S',desc=u'Referring Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Referring Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DN', u'P3'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Referring Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'RF'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes=u'PRV05',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Referring Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420G = Loop( u'2420G', Properties(looptype='',repeat=u'4',pos=u'500',req_sit=u'S',desc=u'Other Payer Prior Authorization or Referral Number'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Other Payer Prior Authorization or Referral Number'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'PR'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'PI', u'XV'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'2',pos=u'525',desc=u'Other Payer Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2430 = Loop( u'2430', Properties(looptype='',repeat=u'25',pos=u'540',req_sit=u'S',desc=u'Line Adjudication Information'),
Segment( u'SVD', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'540',desc=u'Line Adjudication Information'),
  Element( u'SVD01', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=1,
    codes=[] ) ),
  Element( u'SVD02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Composite( u'C003', Properties(req_sit=u'R',refdes='',seq=u'03',desc=u'Procedure Identifier'),
    Element( u'SVD03-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC', u'IV', u'ZZ'] ) ),
    Element( u'SVD03-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SVD03-03', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SVD03-04', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SVD03-05', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SVD03-06', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SVD03-07', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SVD04', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=4,
    codes=[] ) ),
  Element( u'SVD05', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=5,
    codes=[] ) ),
  Element( u'SVD06', Properties(desc=u'Assigned Number', req_sit=u'S', data_type=(u'N0',u'1',u'6'), position=6,
    codes=[] ) ),
),
Segment( u'CAS', Properties(syntax=u'L050607 C0605 C0705 L080910 C0908 C1008 L111213 C1211 C1311 L141516 C1514 C1614 L171819 C1817 C1917',req_sit=u'S',repeat=u'99',pos=u'545',desc=u'Line Adjustment'),
  Element( u'CAS01', Properties(desc=u'Claim Adjustment Group Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[u'CO', u'CR', u'OA', u'PI', u'PR'] ) ),
  Element( u'CAS02', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'5'), position=2,
    codes=[] ) ),
  Element( u'CAS03', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'CAS04', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'CAS05', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=5,
    codes=[] ) ),
  Element( u'CAS06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'CAS07', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CAS08', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=8,
    codes=[] ) ),
  Element( u'CAS09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'CAS10', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CAS11', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=11,
    codes=[] ) ),
  Element( u'CAS12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'CAS13', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=13,
    codes=[] ) ),
  Element( u'CAS14', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=14,
    codes=[] ) ),
  Element( u'CAS15', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=15,
    codes=[] ) ),
  Element( u'CAS16', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CAS17', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=17,
    codes=[] ) ),
  Element( u'CAS18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'CAS19', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=19,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'550',desc=u'Line Adjudication Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'573'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
)
parsed_837_2440 = Loop( u'2440', Properties(looptype='',repeat=u'5',pos=u'551',req_sit=u'S',desc=u'Form Identification Code'),
Segment( u'LQ', Properties(syntax=u'C0102',req_sit=u'R',repeat=u'1',pos=u'551',desc=u'Form Identification Code'),
  Element( u'LQ01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AS', u'UT'] ) ),
  Element( u'LQ02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=2,
    codes=[] ) ),
),
Segment( u'FRM', Properties(syntax=u'R02030405',req_sit=u'R',repeat=u'99',pos=u'552',desc=u'Supporting Documentation'),
  Element( u'FRM01', Properties(desc=u'Assigned Identification', req_sit=u'R', data_type=(u'AN',u'1',u'20'), position=1,
    codes=[] ) ),
  Element( u'FRM02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'W', u'Y'] ) ),
  Element( u'FRM03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'FRM04', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=4,
    codes=[] ) ),
  Element( u'FRM05', Properties(desc=u'Percent, Decimal Format', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=5,
    codes=[] ) ),
),
)
parsed_837_2400 = Loop( u'2400', Properties(looptype='',repeat=u'50',pos=u'365',req_sit=u'R',desc=u'Service Line'),
Segment( u'LX', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'365',desc=u'Service Line'),
  Element( u'LX01', Properties(desc=u'Assigned Number', req_sit=u'R', data_type=(u'N0',u'1',u'6'), position=1,
    codes=[] ) ),
),
Segment( u'SV1', Properties(syntax=u'P0304',req_sit=u'R',repeat=u'1',pos=u'370',desc=u'Professional Service'),
  Composite( u'C003', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Procedure Identifier'),
    Element( u'SV101-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC', u'IV', u'N4', u'ZZ'] ) ),
    Element( u'SV101-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SV101-03', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SV101-04', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SV101-05', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SV101-06', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SV101-07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SV102', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'SV103', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'F2', u'MJ', u'UN'] ) ),
  Element( u'SV104', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'SV105', Properties(desc=u'Facility Code Value', req_sit=u'S', data_type=(u'AN',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'SV106', Properties(desc=u'Service Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Composite( u'C004', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Diagnosis Code Pointer'),
    Element( u'SV107-01', Properties(desc=u'Diagnosis Code Pointer', req_sit=u'R', data_type=(u'N0',u'1',u'2'), position=0,
      codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
    Element( u'SV107-02', Properties(desc=u'Diagnosis Code Pointer', req_sit=u'S', data_type=(u'N0',u'1',u'2'), position=1,
      codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
    Element( u'SV107-03', Properties(desc=u'Diagnosis Code Pointer', req_sit=u'S', data_type=(u'N0',u'1',u'2'), position=2,
      codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
    Element( u'SV107-04', Properties(desc=u'Diagnosis Code Pointer', req_sit=u'S', data_type=(u'N0',u'1',u'2'), position=3,
      codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
  ),
  Element( u'SV108', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'SV109', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'Y'] ) ),
  Element( u'SV110', Properties(desc=u'Multiple Procedure Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=10,
    codes=[] ) ),
  Element( u'SV111', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=11,
    codes=[u'Y'] ) ),
  Element( u'SV112', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=12,
    codes=[u'Y'] ) ),
  Element( u'SV113', Properties(desc=u'Review Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=13,
    codes=[] ) ),
  Element( u'SV114', Properties(desc=u'National or Local Assigned Review Value', req_sit=u'N', data_type=(u'AN',u'1',u'2'), position=14,
    codes=[] ) ),
  Element( u'SV115', Properties(desc=u'Copay Status Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[u'0'] ) ),
  Element( u'SV116', Properties(desc=u'Health Care Professional Shortage Area Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=16,
    codes=[] ) ),
  Element( u'SV117', Properties(desc=u'Reference Identification', req_sit=u'N', data_type=(u'AN',u'1',u'50'), position=17,
    codes=[] ) ),
  Element( u'SV118', Properties(desc=u'Postal Code', req_sit=u'N', data_type=(u'ID',u'3',u'15'), position=18,
    codes=[] ) ),
  Element( u'SV119', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=19,
    codes=[] ) ),
  Element( u'SV120', Properties(desc=u'Level of Care Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=20,
    codes=[] ) ),
  Element( u'SV121', Properties(desc=u'Provider Agreement Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=21,
    codes=[] ) ),
),
Segment( u'SV5', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'400',desc=u'Durable Medical Equipment Service'),
  Composite( u'C003', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Composite Medical Procedure Identifier'),
    Element( u'SV501-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC'] ) ),
    Element( u'SV501-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SV501-03', Properties(desc=u'Procedure Modifier', req_sit=u'N', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SV501-04', Properties(desc=u'Procedure Modifier', req_sit=u'N', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SV501-05', Properties(desc=u'Procedure Modifier', req_sit=u'N', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SV501-06', Properties(desc=u'Procedure Modifier', req_sit=u'N', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SV501-07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SV502', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'DA'] ) ),
  Element( u'SV503', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=3,
    codes=[] ) ),
  Element( u'SV504', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=4,
    codes=[] ) ),
  Element( u'SV505', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=5,
    codes=[] ) ),
  Element( u'SV506', Properties(desc=u'Frequency Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'1', u'4', u'6'] ) ),
  Element( u'SV507', Properties(desc=u'Prognosis Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[] ) ),
),
Segment( u'PWK', Properties(syntax=u'P0506',req_sit=u'S',repeat=u'1',pos=u'420',desc=u'DMERC CMN Indicator'),
  Element( u'PWK01', Properties(desc=u'Report Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'CT'] ) ),
  Element( u'PWK02', Properties(desc=u'Report Transmission Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[u'AB', u'AD', u'AF', u'AG', u'NS'] ) ),
  Element( u'PWK03', Properties(desc=u'Report Copies Needed', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'PWK04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'PWK05', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'PWK06', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=6,
    codes=[] ) ),
  Element( u'PWK07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=7,
    codes=[] ) ),
  Composite( u'C002', Properties(req_sit=u'N',refdes=u'PWK08',seq=u'08',desc=u'Actions Indicated'),
  ),
  Element( u'PWK09', Properties(desc=u'Request Category Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[] ) ),
),
Segment( u'CR1', Properties(syntax=u'P0102 P0506',req_sit=u'S',repeat=u'1',pos=u'425',desc=u'Ambulance Transport Information'),
  Element( u'CR101', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'LB'] ) ),
  Element( u'CR102', Properties(desc=u'Weight', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=2,
    codes=[] ) ),
  Element( u'CR103', Properties(desc=u'Ambulance Transport Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'I', u'R', u'T', u'X'] ) ),
  Element( u'CR104', Properties(desc=u'Ambulance Transport Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'A', u'B', u'C', u'D', u'E'] ) ),
  Element( u'CR105', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'DH'] ) ),
  Element( u'CR106', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR107', Properties(desc=u'Address Information', req_sit=u'N', data_type=(u'AN',u'1',u'55'), position=7,
    codes=[] ) ),
  Element( u'CR108', Properties(desc=u'Address Information', req_sit=u'N', data_type=(u'AN',u'1',u'55'), position=8,
    codes=[] ) ),
  Element( u'CR109', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=9,
    codes=[] ) ),
  Element( u'CR110', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=10,
    codes=[] ) ),
),
Segment( u'CR2', Properties(syntax=u'P0102 C0403 P0506',req_sit=u'S',repeat=u'5',pos=u'430',desc=u'Spinal Manipulation Service Information'),
  Element( u'CR201', Properties(desc=u'Count', req_sit=u'N', data_type=(u'N0',u'1',u'9'), position=1,
    codes=[] ) ),
  Element( u'CR202', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'CR203', Properties(desc=u'Subluxation Level Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'C1', u'C2', u'C3', u'C4', u'C5', u'C6', u'C7', u'CO', u'IL', u'L1', u'L2', u'L3', u'L4', u'L5', u'OC', u'SA', u'T1', u'T2', u'T3', u'T4', u'T5', u'T6', u'T7', u'T8', u'T9', u'T10', u'T11', u'T12'] ) ),
  Element( u'CR204', Properties(desc=u'Subluxation Level Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'C1', u'C2', u'C3', u'C4', u'C5', u'C6', u'C7', u'CO', u'IL', u'L1', u'L2', u'L3', u'L4', u'L5', u'OC', u'SA', u'T1', u'T2', u'T3', u'T4', u'T5', u'T6', u'T7', u'T8', u'T9', u'T10', u'T11', u'T12'] ) ),
  Element( u'CR205', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'DA', u'MO', u'WK', u'YR'] ) ),
  Element( u'CR206', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR207', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CR208', Properties(desc=u'Nature of Condition Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'A', u'C', u'D', u'E', u'F', u'G', u'M'] ) ),
  Element( u'CR209', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'N', u'Y'] ) ),
  Element( u'CR210', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=10,
    codes=[] ) ),
  Element( u'CR211', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=11,
    codes=[] ) ),
  Element( u'CR212', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=12,
    codes=[u'N', u'Y'] ) ),
),
Segment( u'CR3', Properties(syntax=u'P0203',req_sit=u'S',repeat=u'1',pos=u'435',desc=u'Durable Medical Equipment Certification'),
  Element( u'CR301', Properties(desc=u'Certification Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'I', u'R', u'S'] ) ),
  Element( u'CR302', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'MO'] ) ),
  Element( u'CR303', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=3,
    codes=[] ) ),
  Element( u'CR304', Properties(desc=u'Insulin Dependent Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'CR305', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=5,
    codes=[] ) ),
),
Segment( u'CR5', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'445',desc=u'Home Oxygen Therapy Information'),
  Element( u'CR501', Properties(desc=u'Certification Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'I', u'R', u'S'] ) ),
  Element( u'CR502', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'CR503', Properties(desc=u'Oxygen Equipment Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
  Element( u'CR504', Properties(desc=u'Oxygen Equipment Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'CR505', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=5,
    codes=[] ) ),
  Element( u'CR506', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR507', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CR508', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=8,
    codes=[] ) ),
  Element( u'CR509', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=9,
    codes=[] ) ),
  Element( u'CR510', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CR511', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=11,
    codes=[] ) ),
  Element( u'CR512', Properties(desc=u'Oxygen Test Condition Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=12,
    codes=[u'E', u'R', u'S'] ) ),
  Element( u'CR513', Properties(desc=u'Oxygen Test Findings Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=13,
    codes=[u'1'] ) ),
  Element( u'CR514', Properties(desc=u'Oxygen Test Findings Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=14,
    codes=[u'2'] ) ),
  Element( u'CR515', Properties(desc=u'Oxygen Test Findings Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[u'3'] ) ),
  Element( u'CR516', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CR517', Properties(desc=u'Oxygen Delivery System Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=17,
    codes=[] ) ),
  Element( u'CR518', Properties(desc=u'Oxygen Equipment Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=18,
    codes=[] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'450',desc=u'Ambulance Certification'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'07'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'450',desc=u'Hospice Employee Indicator'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'70'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'65'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'450',desc=u'DMERC Condition Indicator'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'09', u'11'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'455',desc=u'Date - Service Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'472'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8', u'RD8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Certification Revision Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'607'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Begin Therapy Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'463'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Last Certification Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'461'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Date Last Seen'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'304'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'455',desc=u'Date - Test'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'738', u'739'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'455',desc=u'Date - Oxygen Saturation/Arterial Blood Gas Test'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'119', u'480', u'481'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Shipped'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'011'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Onset of Current Symptom/Illness'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'431'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Last X-ray'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'455'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Acute Manifestation'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'453'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Initial Treatment'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'454'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Similar Illness/Symptom Onset'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'438'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'MEA', Properties(syntax=u'R03050608 C0504 C0604 L07030506 E0803',req_sit=u'S',repeat=u'20',pos=u'462',desc=u'Test Result'),
  Element( u'MEA01', Properties(desc=u'Measurement Reference ID Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'OG', u'TR'] ) ),
  Element( u'MEA02', Properties(desc=u'Measurement Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=2,
    codes=[u'GRA', u'HT', u'R1', u'R2', u'R3', u'R4', u'ZO'] ) ),
  Element( u'MEA03', Properties(desc=u'Measurement Value', req_sit=u'R', data_type=(u'R',u'1',u'20'), position=3,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Composite Unit of Measure'),
  ),
  Element( u'MEA05', Properties(desc=u'Range Minimum', req_sit=u'N', data_type=(u'R',u'1',u'20'), position=5,
    codes=[] ) ),
  Element( u'MEA06', Properties(desc=u'Range Maximum', req_sit=u'N', data_type=(u'R',u'1',u'20'), position=6,
    codes=[] ) ),
  Element( u'MEA07', Properties(desc=u'Measurement Significance Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[] ) ),
  Element( u'MEA08', Properties(desc=u'Measurement Attribute Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[] ) ),
  Element( u'MEA09', Properties(desc=u'Surface/Layer/Position Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[] ) ),
  Element( u'MEA10', Properties(desc=u'Measurement Method or Device', req_sit=u'N', data_type=(u'ID',u'2',u'4'), position=10,
    codes=[] ) ),
),
Segment( u'CN1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'465',desc=u'Contract Information'),
  Element( u'CN101', Properties(desc=u'Contract Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'09'] ) ),
  Element( u'CN102', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CN103', Properties(desc=u'Percent, Decimal Format', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=3,
    codes=[] ) ),
  Element( u'CN104', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'CN105', Properties(desc=u'Terms Discount Percent', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=5,
    codes=[] ) ),
  Element( u'CN106', Properties(desc=u'Version Identifier', req_sit=u'S', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Repriced Line Item Reference Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9B'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Adjusted Repriced Line Item Reference Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9D'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'470',desc=u'Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'4',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Line Item Control Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'6R'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Mammography Certification Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'EW'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Clinical Laboratory Improvement Amendment (CLIA) Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'X4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Referring Clinical Laboratory Improvement Amendment (CLIA) Facility Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'F4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Immunization Batch Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'BT'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'4',pos=u'470',desc=u'Ambulatory Patient Group (APG)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1S'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Oxygen Flow Rate'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'TP'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Universal Product Number (UPN)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'OZ', u'VP'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Sales Tax Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'T'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Approved Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AAE'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Postage Claimed Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F4'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'K3', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'480',desc=u'File Information'),
  Element( u'K301', Properties(desc=u'Fixed Format Information', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=1,
    codes=[] ) ),
  Element( u'K302', Properties(desc=u'Record Format Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'N',refdes=u'K303',seq=u'03',desc=u'Composite Unit of Measure'),
  ),
),
Segment( u'NTE', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'485',desc=u'Line Note'),
  Element( u'NTE01', Properties(desc=u'Note Reference Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'ADD', u'DCP', u'PMT', u'TPO'] ) ),
  Element( u'NTE02', Properties(desc=u'Description', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=2,
    codes=[] ) ),
),
Segment( u'PS1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'488',desc=u'Purchased Service Information'),
  Element( u'PS101', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=1,
    codes=[] ) ),
  Element( u'PS102', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'PS103', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[] ) ),
),
Segment( u'HSD', Properties(syntax=u'P0102 C0605',req_sit=u'S',repeat=u'1',pos=u'491',desc=u'Health Care Services Delivery'),
  Element( u'HSD01', Properties(desc=u'Quantity Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'VS'] ) ),
  Element( u'HSD02', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'HSD03', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'DA', u'MO', u'Q1', u'WK'] ) ),
  Element( u'HSD04', Properties(desc=u'Sample Selection Modulus', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=4,
    codes=[] ) ),
  Element( u'HSD05', Properties(desc=u'Time Period Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'7', u'34', u'35'] ) ),
  Element( u'HSD06', Properties(desc=u'Number of Periods', req_sit=u'S', data_type=(u'N0',u'1',u'3'), position=6,
    codes=[] ) ),
  Element( u'HSD07', Properties(desc=u'Ship/Delivery or Calendar Pattern Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=7,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'J', u'K', u'L', u'N', u'O', u'W', u'SA', u'SB', u'SC', u'SD', u'SG', u'SL', u'SP', u'SX', u'SY', u'SZ'] ) ),
  Element( u'HSD08', Properties(desc=u'Ship/Delivery Pattern Time Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'D', u'E', u'F'] ) ),
),
Segment( u'HCP', Properties(syntax=u'R0113 P0910 P1112',req_sit=u'S',repeat=u'1',pos=u'492',desc=u'Line Pricing/Repricing Information'),
  Element( u'HCP01', Properties(desc=u'Pricing Methodology', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'10', u'11', u'12', u'13', u'14'] ) ),
  Element( u'HCP02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'HCP03', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'HCP04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'HCP05', Properties(desc=u'Rate', req_sit=u'S', data_type=(u'R',u'1',u'9'), position=5,
    codes=[] ) ),
  Element( u'HCP06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'HCP07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'HCP08', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=8,
    codes=[] ) ),
  Element( u'HCP09', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[u'HC', u'IV', u'ZZ'] ) ),
  Element( u'HCP10', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=10,
    codes=[] ) ),
  Element( u'HCP11', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=11,
    codes=[u'DA', u'UN'] ) ),
  Element( u'HCP12', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=12,
    codes=[] ) ),
  Element( u'HCP13', Properties(desc=u'Reject Reason Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=13,
    codes=[u'T1', u'T2', u'T3', u'T4', u'T5', u'T6'] ) ),
  Element( u'HCP14', Properties(desc=u'Policy Compliance Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5'] ) ),
  Element( u'HCP15', Properties(desc=u'Exception Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=15,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6'] ) ),
),
parsed_837_2410,
parsed_837_2420A,
parsed_837_2420B,
parsed_837_2420C,
parsed_837_2420D,
parsed_837_2420E,
parsed_837_2420F,
parsed_837_2420G,
parsed_837_2430,
parsed_837_2440,
)
parsed_837_2300 = Loop( u'2300', Properties(looptype='',repeat=u'100',pos=u'130',req_sit=u'S',desc=u'Claim Information'),
Segment( u'CLM', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'130',desc=u'Claim Information'),
  Element( u'CLM01', Properties(desc=u"Claim Submitter's Identifier", req_sit=u'R', data_type=(u'AN',u'1',u'38'), position=1,
    codes=[] ) ),
  Element( u'CLM02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CLM03', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'CLM04', Properties(desc=u'Non-Institutional Claim Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C023', Properties(req_sit=u'R',refdes='',seq=u'05',desc=u'Place of Service Code'),
    Element( u'CLM05-01', Properties(desc=u'Facility Code Value', req_sit=u'R', data_type=(u'AN',u'1',u'2'), position=0,
      codes=[] ) ),
    Element( u'CLM05-02', Properties(desc=u'Facility Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=1,
      codes=[] ) ),
    Element( u'CLM05-03', Properties(desc=u'Claim Frequency Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
      codes=[] ) ),
  ),
  Element( u'CLM06', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM07', Properties(desc=u'Provider Accept Assignment Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[u'A', u'B', u'C', u'P'] ) ),
  Element( u'CLM08', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM09', Properties(desc=u'Release of Information Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'A', u'I', u'M', u'N', u'O', u'Y'] ) ),
  Element( u'CLM10', Properties(desc=u'Patient Signature Source Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=10,
    codes=[u'B', u'C', u'M', u'P', u'S'] ) ),
  Composite( u'C024', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Accident/Employment/Related Causes'),
    Element( u'CLM11-01', Properties(desc=u'Related-Causes Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=0,
      codes=[u'AA', u'AP', u'EM', u'OA'] ) ),
    Element( u'CLM11-02', Properties(desc=u'Related-Causes Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=1,
      codes=[u'AA', u'AP', u'EM', u'OA'] ) ),
    Element( u'CLM11-03', Properties(desc=u'Related-Causes Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'AA', u'AP', u'EM', u'OA'] ) ),
    Element( u'CLM11-04', Properties(desc=u'State or Province Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'CLM11-05', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
      codes=[] ) ),
  ),
  Element( u'CLM12', Properties(desc=u'Special Program Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=12,
    codes=[u'01', u'02', u'03', u'05', u'07', u'08', u'09'] ) ),
  Element( u'CLM13', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=13,
    codes=[] ) ),
  Element( u'CLM14', Properties(desc=u'Level of Service Code', req_sit=u'N', data_type=(u'ID',u'1',u'3'), position=14,
    codes=[] ) ),
  Element( u'CLM15', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[] ) ),
  Element( u'CLM16', Properties(desc=u'Provider Agreement Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=16,
    codes=[u'P'] ) ),
  Element( u'CLM17', Properties(desc=u'Claim Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=17,
    codes=[] ) ),
  Element( u'CLM18', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=18,
    codes=[] ) ),
  Element( u'CLM19', Properties(desc=u'Claim Submission Reason Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=19,
    codes=[] ) ),
  Element( u'CLM20', Properties(desc=u'Delay Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=20,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11'] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Initial Treatment'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'454'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Date Last Seen'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'304'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Onset of Current Illness/Symptom'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'431'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'135',desc=u'Date - Acute Manifestation'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'453'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'135',desc=u'Date - Similar Illness/Symptom Onset'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'438'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'135',desc=u'Date - Accident'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'439'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8', u'DT'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Last Menstrual Period'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'484'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Last X-Ray'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'455'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Hearing and Vision Prescription Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'471'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'135',desc=u'Date - Disability Begin'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'360'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'135',desc=u'Date - Disability End'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'361'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Last Worked'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'297'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Authorized Return to Work'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'296'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Admission'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'435'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Discharge'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'096'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'135',desc=u'Date - Assumed and Relinquished Care Dates'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'090', u'091'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'PWK', Properties(syntax=u'P0506',req_sit=u'S',repeat=u'10',pos=u'155',desc=u'Claim Supplemental Information'),
  Element( u'PWK01', Properties(desc=u'Report Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'77', u'AS', u'B2', u'B3', u'B4', u'CT', u'DA', u'DG', u'DS', u'EB', u'MT', u'NN', u'OB', u'OZ', u'PN', u'PO', u'PZ', u'RB', u'RR', u'RT'] ) ),
  Element( u'PWK02', Properties(desc=u'Report Transmission Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[u'AA', u'BM', u'EL', u'EM', u'FX'] ) ),
  Element( u'PWK03', Properties(desc=u'Report Copies Needed', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'PWK04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'PWK05', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'AC'] ) ),
  Element( u'PWK06', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=6,
    codes=[] ) ),
  Element( u'PWK07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=7,
    codes=[] ) ),
  Composite( u'C002', Properties(req_sit=u'N',refdes=u'PWK08',seq=u'08',desc=u'Actions Indicated'),
  ),
  Element( u'PWK09', Properties(desc=u'Request Category Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[] ) ),
),
Segment( u'CN1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'160',desc=u'Contract Information'),
  Element( u'CN101', Properties(desc=u'Contract Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'02', u'03', u'04', u'05', u'06', u'09'] ) ),
  Element( u'CN102', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CN103', Properties(desc=u'Percent, Decimal Format', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=3,
    codes=[] ) ),
  Element( u'CN104', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'CN105', Properties(desc=u'Terms Discount Percent', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=5,
    codes=[] ) ),
  Element( u'CN106', Properties(desc=u'Version Identifier', req_sit=u'S', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Credit/Debit Card Maximum Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'MA'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Patient Amount Paid'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F5'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Total Purchased Service Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'NE'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Service Authorization Exception Code'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'4N'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Mandatory Medicare (Section 4081) Crossover Indicator'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'F5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'Y', u'N'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Mammography Certification Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'EW'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'180',desc=u'Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Original Reference Number (ICN/DCN)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'F8'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'3',pos=u'180',desc=u'Clinical Laboratory Improvement Amendment (CLIA) Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'X4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Repriced Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9A'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Adjusted Repriced Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9C'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Investigational Device Exemption Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'LX'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Claim Identification Number for Clearing Houses and Other Transmission Intermediaries'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D9'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'4',pos=u'180',desc=u'Ambulatory Patient Group (APG)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1S'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Medical Record Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'EA'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Demonstration Project Identifier'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'P4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'K3', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'185',desc=u'File Information'),
  Element( u'K301', Properties(desc=u'Fixed Format Information', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=1,
    codes=[] ) ),
  Element( u'K302', Properties(desc=u'Record Format Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'N',refdes=u'K303',seq=u'03',desc=u'Composite Unit of Measure'),
  ),
),
Segment( u'NTE', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'190',desc=u'Claim Note'),
  Element( u'NTE01', Properties(desc=u'Note Reference Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'ADD', u'CER', u'DCP', u'DGN', u'PMT', u'TPO'] ) ),
  Element( u'NTE02', Properties(desc=u'Description', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=2,
    codes=[] ) ),
),
Segment( u'CR1', Properties(syntax=u'P0102 P0506',req_sit=u'S',repeat=u'1',pos=u'195',desc=u'Ambulance Transport Information'),
  Element( u'CR101', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'LB'] ) ),
  Element( u'CR102', Properties(desc=u'Weight', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=2,
    codes=[] ) ),
  Element( u'CR103', Properties(desc=u'Ambulance Transport Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'I', u'R', u'T', u'X'] ) ),
  Element( u'CR104', Properties(desc=u'Ambulance Transport Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'A', u'B', u'C', u'D', u'E'] ) ),
  Element( u'CR105', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'DH'] ) ),
  Element( u'CR106', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR107', Properties(desc=u'Address Information', req_sit=u'N', data_type=(u'AN',u'1',u'55'), position=7,
    codes=[] ) ),
  Element( u'CR108', Properties(desc=u'Address Information', req_sit=u'N', data_type=(u'AN',u'1',u'55'), position=8,
    codes=[] ) ),
  Element( u'CR109', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=9,
    codes=[] ) ),
  Element( u'CR110', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=10,
    codes=[] ) ),
),
Segment( u'CR2', Properties(syntax=u'P0102 C0403 P0506',req_sit=u'S',repeat=u'1',pos=u'200',desc=u'Spinal Manipulation Service Information'),
  Element( u'CR201', Properties(desc=u'Count', req_sit=u'N', data_type=(u'N0',u'1',u'9'), position=1,
    codes=[] ) ),
  Element( u'CR202', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'CR203', Properties(desc=u'Subluxation Level Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'C1', u'C2', u'C3', u'C4', u'C5', u'C6', u'C7', u'CO', u'IL', u'L1', u'L2', u'L3', u'L4', u'L5', u'OC', u'SA', u'T1', u'T2', u'T3', u'T4', u'T5', u'T6', u'T7', u'T8', u'T9', u'T10', u'T11', u'T12'] ) ),
  Element( u'CR204', Properties(desc=u'Subluxation Level Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'C1', u'C2', u'C3', u'C4', u'C5', u'C6', u'C7', u'CO', u'IL', u'L1', u'L2', u'L3', u'L4', u'L5', u'OC', u'SA', u'T1', u'T2', u'T3', u'T4', u'T5', u'T6', u'T7', u'T8', u'T9', u'T10', u'T11', u'T12'] ) ),
  Element( u'CR205', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'DA', u'MO', u'WK', u'YR'] ) ),
  Element( u'CR206', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR207', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CR208', Properties(desc=u'Nature of Condition Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'A', u'C', u'D', u'E', u'F', u'G', u'M'] ) ),
  Element( u'CR209', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'N', u'Y'] ) ),
  Element( u'CR210', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=10,
    codes=[] ) ),
  Element( u'CR211', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=11,
    codes=[] ) ),
  Element( u'CR212', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=12,
    codes=[u'N', u'Y'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'220',desc=u'Ambulance Certification'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'07'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'220',desc=u'Patient Condition Information:  Vision'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'E1', u'E2', u'E3'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'220',desc=u'Homebound Indicator'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'75'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'IH'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'220',desc=u'EPSDT Referral'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'ZZ'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'AV', u'NU', u'S2', u'ST'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'AV', u'NU', u'S2', u'ST'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'AV', u'NU', u'S2', u'ST'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'231',desc=u'Health Care Diagnosis Code'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Principal Diagnosis'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BK'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Diagnosis'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Diagnosis'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Diagnosis'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Diagnosis'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Diagnosis'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Diagnosis'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Diagnosis'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes=u'HI09',seq=u'09',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes=u'HI10',seq=u'10',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes=u'HI11',seq=u'11',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes=u'HI12',seq=u'12',desc=u'Health Care Code Information'),
  ),
),
Segment( u'HCP', Properties(syntax=u'R0113 P0910 P1112',req_sit=u'S',repeat=u'1',pos=u'241',desc=u'Claim Pricing/Repricing Information'),
  Element( u'HCP01', Properties(desc=u'Pricing Methodology', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'01', u'02', u'03', u'04', u'05', u'07', u'08', u'09', u'10', u'11', u'12', u'13', u'14'] ) ),
  Element( u'HCP02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'HCP03', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'HCP04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'HCP05', Properties(desc=u'Rate', req_sit=u'S', data_type=(u'R',u'1',u'9'), position=5,
    codes=[] ) ),
  Element( u'HCP06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'HCP07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'HCP08', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=8,
    codes=[] ) ),
  Element( u'HCP09', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[] ) ),
  Element( u'HCP10', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=10,
    codes=[] ) ),
  Element( u'HCP11', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=11,
    codes=[] ) ),
  Element( u'HCP12', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=12,
    codes=[] ) ),
  Element( u'HCP13', Properties(desc=u'Reject Reason Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=13,
    codes=[u'T1', u'T2', u'T3', u'T4', u'T5', u'T6'] ) ),
  Element( u'HCP14', Properties(desc=u'Policy Compliance Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5'] ) ),
  Element( u'HCP15', Properties(desc=u'Exception Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=15,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6'] ) ),
),
parsed_837_2305,
parsed_837_2310A,
parsed_837_2310B,
parsed_837_2310C,
parsed_837_2310D,
parsed_837_2310E,
parsed_837_2320,
parsed_837_2400,
)
parsed_837_2010CA = Loop( u'2010CA', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'R',desc=u'Patient Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Patient Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QC'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI', u'ZZ'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'025',desc=u'Patient Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Patient City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'DMG', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'032',desc=u'Patient Demographic Information'),
  Element( u'DMG01', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'DMG02', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=2,
    codes=[] ) ),
  Element( u'DMG03', Properties(desc=u'Gender Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'F', u'M', u'U'] ) ),
  Element( u'DMG04', Properties(desc=u'Marital Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'DMG05', Properties(desc=u'Race or Ethnicity Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'DMG06', Properties(desc=u'Citizenship Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Element( u'DMG07', Properties(desc=u'Country Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
  Element( u'DMG08', Properties(desc=u'Basis of Verification Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'DMG09', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=9,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'035',desc=u'Patient Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'035',desc=u'Property and Casualty Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'Y4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2305 = Loop( u'2305', Properties(looptype='',repeat=u'6',pos=u'242',req_sit=u'S',desc=u'Home Health Care Plan Information'),
Segment( u'CR7', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'242',desc=u'Home Health Care Plan Information'),
  Element( u'CR701', Properties(desc=u'Discipline Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'AI', u'MS', u'OT', u'PT', u'SN', u'ST'] ) ),
  Element( u'CR702', Properties(desc=u'Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=2,
    codes=[] ) ),
  Element( u'CR703', Properties(desc=u'Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=3,
    codes=[] ) ),
),
Segment( u'HSD', Properties(syntax=u'P0102 C0605',req_sit=u'S',repeat=u'3',pos=u'243',desc=u'Health Care Services Delivery'),
  Element( u'HSD01', Properties(desc=u'Quantity Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'VS'] ) ),
  Element( u'HSD02', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'HSD03', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'DA', u'MO', u'Q1', u'WK'] ) ),
  Element( u'HSD04', Properties(desc=u'Sample Selection Modulus', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=4,
    codes=[] ) ),
  Element( u'HSD05', Properties(desc=u'Time Period Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'7', u'35'] ) ),
  Element( u'HSD06', Properties(desc=u'Number of Periods', req_sit=u'S', data_type=(u'N0',u'1',u'3'), position=6,
    codes=[] ) ),
  Element( u'HSD07', Properties(desc=u'Ship/Delivery or Calendar Pattern Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=7,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'J', u'K', u'L', u'N', u'O', u'S', u'W', u'SA', u'SB', u'SC', u'SD', u'SG', u'SL', u'SP', u'SX', u'SY', u'SZ'] ) ),
  Element( u'HSD08', Properties(desc=u'Ship/Delivery Pattern Time Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'D', u'E', u'F'] ) ),
),
)
parsed_837_2310A = Loop( u'2310A', Properties(looptype='',repeat=u'2',pos=u'250',req_sit=u'S',desc=u'Referring Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Referring Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DN', u'P3'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Referring Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'RF'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes=u'PRV05',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Referring Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310B = Loop( u'2310B', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Rendering Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Rendering Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'82'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Rendering Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'PE'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes=u'PRV05',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Rendering Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310C = Loop( u'2310C', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Purchased Service Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Purchased Service Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QB'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Purchased Service Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'U3', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310D = Loop( u'2310D', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Service Facility Location'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Service Facility Location'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'77', u'FA', u'LI', u'TL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'265',desc=u'Service Facility Location Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'R',repeat=u'1',pos=u'270',desc=u'Service Facility Location City/State/ZIP'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Service Facility Location Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'G2', u'LU', u'N5', u'TJ', u'X4', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310E = Loop( u'2310E', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Supervising Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Supervising Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DQ'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Supervising Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330A = Loop( u'2330A', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'R',desc=u'Other Subscriber Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Subscriber Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'IL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI', u'ZZ'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'332',desc=u'Other Subscriber Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'S',repeat=u'1',pos=u'340',desc=u'Other Subscriber City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'S', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'S', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'3',pos=u'355',desc=u'Other Subscriber Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330B = Loop( u'2330B', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'R',desc=u'Other Payer Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'PR'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'PI', u'XV'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PER', Properties(syntax=u'P0304 P0506 P0708',req_sit=u'S',repeat=u'2',pos=u'345',desc=u'Other Payer Contact Information'),
  Element( u'PER01', Properties(desc=u'Contact Function Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'IC'] ) ),
  Element( u'PER02', Properties(desc=u'Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=2,
    codes=[] ) ),
  Element( u'PER03', Properties(desc=u'Communication Number Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'ED', u'EM', u'FX', u'TE'] ) ),
  Element( u'PER04', Properties(desc=u'Communication Number', req_sit=u'R', data_type=(u'AN',u'1',u'256'), position=4,
    codes=[] ) ),
  Element( u'PER05', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'ED', u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER06', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=6,
    codes=[] ) ),
  Element( u'PER07', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'ED', u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER08', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=8,
    codes=[] ) ),
  Element( u'PER09', Properties(desc=u'Contact Inquiry Reference', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=9,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'345',desc=u'Claim Adjudication Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'573'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'355',desc=u'Other Payer Secondary Identifier'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'2U', u'F8', u'FY', u'NF', u'TJ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'355',desc=u'Other Payer Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'355',desc=u'Other Payer Claim Adjustment Indicator'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'T4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'Y'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330C = Loop( u'2330C', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Patient Information'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Patient Information'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QC'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'3',pos=u'355',desc=u'Other Payer Patient Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330D = Loop( u'2330D', Properties(looptype='',repeat=u'2',pos=u'325',req_sit=u'S',desc=u'Other Payer Referring Provider'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Referring Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DN', u'P3'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Referring Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1B', u'1C', u'1D', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330E = Loop( u'2330E', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Rendering Provider'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Rendering Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'82'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Rendering Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1B', u'1C', u'1D', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330F = Loop( u'2330F', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Purchased Service Provider'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Purchased Service Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QB'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Purchased Service Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330G = Loop( u'2330G', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Service Facility Location'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Service Facility Location'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'77', u'FA', u'LI', u'TL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Service Facility Location Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330H = Loop( u'2330H', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Supervising Provider'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Supervising Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DQ'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Supervising Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1B', u'1C', u'1D', u'EI', u'G2', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2320 = Loop( u'2320', Properties(looptype='',repeat=u'10',pos=u'290',req_sit=u'S',desc=u'Other Subscriber Information'),
Segment( u'SBR', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'290',desc=u'Other Subscriber Information'),
  Element( u'SBR01', Properties(desc=u'Payer Responsibility Sequence Number Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'P', u'S', u'T'] ) ),
  Element( u'SBR02', Properties(desc=u'Individual Relationship Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'01', u'04', u'05', u'07', u'10', u'15', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'29', u'32', u'33', u'36', u'39', u'40', u'41', u'43', u'53', u'G8'] ) ),
  Element( u'SBR03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'SBR04', Properties(desc=u'Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=4,
    codes=[] ) ),
  Element( u'SBR05', Properties(desc=u'Insurance Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=5,
    codes=[u'AP', u'C1', u'CP', u'GP', u'HM', u'IP', u'LD', u'LT', u'MB', u'MC', u'MI', u'MP', u'OT', u'PP', u'SP'] ) ),
  Element( u'SBR06', Properties(desc=u'Coordination of Benefits Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[] ) ),
  Element( u'SBR07', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[] ) ),
  Element( u'SBR08', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[] ) ),
  Element( u'SBR09', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[u'09', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'AM', u'BL', u'CH', u'CI', u'DS', u'HM', u'LI', u'LM', u'MB', u'MC', u'OF', u'TV', u'VA', u'WC', u'ZZ'] ) ),
),
Segment( u'CAS', Properties(syntax=u'L050607 C0605 C0705 L080910 C0908 C1008 L111213 C1211 C1311 L141516 C1514 C1614 L171819 C1817 C1917',req_sit=u'S',repeat=u'5',pos=u'295',desc=u'Claim Level Adjustments'),
  Element( u'CAS01', Properties(desc=u'Claim Adjustment Group Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[u'CO', u'CR', u'OA', u'PI', u'PR'] ) ),
  Element( u'CAS02', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'5'), position=2,
    codes=[] ) ),
  Element( u'CAS03', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'CAS04', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'CAS05', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=5,
    codes=[] ) ),
  Element( u'CAS06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'CAS07', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CAS08', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=8,
    codes=[] ) ),
  Element( u'CAS09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'CAS10', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CAS11', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=11,
    codes=[] ) ),
  Element( u'CAS12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'CAS13', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=13,
    codes=[] ) ),
  Element( u'CAS14', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=14,
    codes=[] ) ),
  Element( u'CAS15', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=15,
    codes=[] ) ),
  Element( u'CAS16', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CAS17', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=17,
    codes=[] ) ),
  Element( u'CAS18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'CAS19', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=19,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Payer Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'D'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Approved Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AAE'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Allowed Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'B6'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Patient Responsibility Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F2'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Covered Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AU'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Discount Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Per Day Limit Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'DY'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Patient Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F5'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Tax Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'T'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Claim Before Taxes Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'T2'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'DMG', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'305',desc=u'Subscriber Demographic Information'),
  Element( u'DMG01', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'DMG02', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=2,
    codes=[] ) ),
  Element( u'DMG03', Properties(desc=u'Gender Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'F', u'M', u'U'] ) ),
  Element( u'DMG04', Properties(desc=u'Marital Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'DMG05', Properties(desc=u'Race or Ethnicity Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'DMG06', Properties(desc=u'Citizenship Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Element( u'DMG07', Properties(desc=u'Country Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
  Element( u'DMG08', Properties(desc=u'Basis of Verification Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'DMG09', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=9,
    codes=[] ) ),
),
Segment( u'OI', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'310',desc=u'Other Insurance Coverage Information'),
  Element( u'OI01', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[] ) ),
  Element( u'OI02', Properties(desc=u'Claim Submission Reason Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'OI03', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'N', u'Y'] ) ),
  Element( u'OI04', Properties(desc=u'Patient Signature Source Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'B', u'C', u'M', u'P', u'S'] ) ),
  Element( u'OI05', Properties(desc=u'Provider Agreement Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'OI06', Properties(desc=u'Release of Information Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'A', u'I', u'M', u'N', u'O', u'Y'] ) ),
),
Segment( u'MOA', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'320',desc=u'Medicare Outpatient Adjudication Information'),
  Element( u'MOA01', Properties(desc=u'Percentage as Decimal', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=1,
    codes=[] ) ),
  Element( u'MOA02', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'MOA03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'MOA04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'MOA05', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=5,
    codes=[] ) ),
  Element( u'MOA06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'MOA07', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=7,
    codes=[] ) ),
  Element( u'MOA08', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'MOA09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
),
parsed_837_2330A,
parsed_837_2330B,
parsed_837_2330C,
parsed_837_2330D,
parsed_837_2330E,
parsed_837_2330F,
parsed_837_2330G,
parsed_837_2330H,
)
parsed_837_2410 = Loop( u'2410', Properties(looptype='',repeat=u'25',pos=u'494',req_sit=u'S',desc=u'Drug Identification'),
Segment( u'LIN', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'494',desc=u'Drug Identification'),
  Element( u'LIN01', Properties(desc=u'Assigned Identification', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=1,
    codes=[] ) ),
  Element( u'LIN02', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'N4'] ) ),
  Element( u'LIN03', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=3,
    codes=[] ) ),
  Element( u'LIN04', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[u'N4'] ) ),
  Element( u'LIN05', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=5,
    codes=[] ) ),
  Element( u'LIN06', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
    codes=[u'N4'] ) ),
  Element( u'LIN07', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=7,
    codes=[] ) ),
  Element( u'LIN08', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[u'N4'] ) ),
  Element( u'LIN09', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=9,
    codes=[] ) ),
  Element( u'LIN10', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[u'N4'] ) ),
  Element( u'LIN11', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=11,
    codes=[] ) ),
  Element( u'LIN12', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
    codes=[u'N4'] ) ),
  Element( u'LIN13', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=13,
    codes=[] ) ),
  Element( u'LIN14', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=14,
    codes=[u'N4'] ) ),
  Element( u'LIN15', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=15,
    codes=[] ) ),
  Element( u'LIN16', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=16,
    codes=[u'N4'] ) ),
  Element( u'LIN17', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=17,
    codes=[] ) ),
  Element( u'LIN18', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=18,
    codes=[u'N4'] ) ),
  Element( u'LIN19', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=19,
    codes=[] ) ),
  Element( u'LIN20', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=20,
    codes=[u'N4'] ) ),
  Element( u'LIN21', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=21,
    codes=[] ) ),
  Element( u'LIN22', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=22,
    codes=[u'N4'] ) ),
  Element( u'LIN23', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=23,
    codes=[] ) ),
  Element( u'LIN24', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=24,
    codes=[u'N4'] ) ),
  Element( u'LIN25', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=25,
    codes=[] ) ),
  Element( u'LIN26', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=26,
    codes=[u'N4'] ) ),
  Element( u'LIN27', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=27,
    codes=[] ) ),
  Element( u'LIN28', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=28,
    codes=[u'N4'] ) ),
  Element( u'LIN29', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=29,
    codes=[] ) ),
  Element( u'LIN30', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=30,
    codes=[u'N4'] ) ),
  Element( u'LIN31', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=31,
    codes=[] ) ),
),
Segment( u'CTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'495',desc=u'Drug Pricing'),
  Element( u'CTP01', Properties(desc=u'Class of Trade Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[] ) ),
  Element( u'CTP02', Properties(desc=u'Price Identifier Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=2,
    codes=[] ) ),
  Element( u'CTP03', Properties(desc=u'Unit Price', req_sit=u'R', data_type=(u'R',u'1',u'17'), position=3,
    codes=[] ) ),
  Element( u'CTP04', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'R',refdes='',seq=u'05',desc=u'Unit or Basis of Measurement'),
    Element( u'CTP05-01', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'F2', u'GR', u'ML', u'UN'] ) ),
    Element( u'CTP05-02', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=1,
      codes=[] ) ),
    Element( u'CTP05-03', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=2,
      codes=[] ) ),
    Element( u'CTP05-04', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'CTP05-05', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=4,
      codes=[] ) ),
    Element( u'CTP05-06', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=5,
      codes=[] ) ),
    Element( u'CTP05-07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
      codes=[] ) ),
    Element( u'CTP05-08', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
      codes=[] ) ),
    Element( u'CTP05-09', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=8,
      codes=[] ) ),
    Element( u'CTP05-10', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
      codes=[] ) ),
    Element( u'CTP05-11', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=10,
      codes=[] ) ),
    Element( u'CTP05-12', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=11,
      codes=[] ) ),
    Element( u'CTP05-13', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
      codes=[] ) ),
    Element( u'CTP05-14', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=13,
      codes=[] ) ),
    Element( u'CTP05-15', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=14,
      codes=[] ) ),
  ),
  Element( u'CTP06', Properties(desc=u'Price Multiplier Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
  Element( u'CTP07', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'CTP08', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'CTP09', Properties(desc=u'Basis of Unit Price Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[] ) ),
  Element( u'CTP10', Properties(desc=u'Condition Value', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=10,
    codes=[] ) ),
  Element( u'CTP11', Properties(desc=u'Multiple Price Quantity', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'496',desc=u'Prescription Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'XZ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420A = Loop( u'2420A', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Rendering Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Rendering Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'82'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Rendering Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'PE'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes=u'PRV05',seq=u'5',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Rendering Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420B = Loop( u'2420B', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Purchased Service Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Purchased Service Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QB'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Purchased Service Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'U3', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420C = Loop( u'2420C', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Service Facility Location'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Service Facility Location'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'77', u'FA', u'LI', u'TL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'514',desc=u'Service Facility Location Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'R',repeat=u'1',pos=u'520',desc=u'Service Facility Location City/State/ZIP'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Service Facility Location Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'G2', u'LU', u'N5', u'TJ', u'X4', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420D = Loop( u'2420D', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Supervising Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Supervising Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DQ'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Supervising Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420E = Loop( u'2420E', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Ordering Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Ordering Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DK'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'514',desc=u'Ordering Provider Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax=u'C0605',req_sit=u'S',repeat=u'1',pos=u'520',desc=u'Ordering Provider City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Ordering Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'PER', Properties(syntax=u'P0304 P0506 P0708',req_sit=u'S',repeat=u'1',pos=u'530',desc=u'Ordering Provider Contact Information'),
  Element( u'PER01', Properties(desc=u'Contact Function Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'IC'] ) ),
  Element( u'PER02', Properties(desc=u'Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=2,
    codes=[] ) ),
  Element( u'PER03', Properties(desc=u'Communication Number Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'EM', u'FX', u'TE'] ) ),
  Element( u'PER04', Properties(desc=u'Communication Number', req_sit=u'R', data_type=(u'AN',u'1',u'256'), position=4,
    codes=[] ) ),
  Element( u'PER05', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER06', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=6,
    codes=[] ) ),
  Element( u'PER07', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER08', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=8,
    codes=[] ) ),
  Element( u'PER09', Properties(desc=u'Contact Inquiry Reference', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=9,
    codes=[] ) ),
),
)
parsed_837_2420F = Loop( u'2420F', Properties(looptype='',repeat=u'2',pos=u'500',req_sit=u'S',desc=u'Referring Provider Name'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Referring Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DN', u'P3'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Referring Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'RF'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'5',pos=u'525',desc=u'Referring Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420G = Loop( u'2420G', Properties(looptype='',repeat=u'4',pos=u'500',req_sit=u'S',desc=u'Other Payer Prior Authorization or Referral Number'),
Segment( u'NM1', Properties(syntax=u'P0809 C1110',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Other Payer Prior Authorization or Referral Number'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'PR'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'PI', u'XV'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'R',repeat=u'2',pos=u'525',desc=u'Other Payer Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2430 = Loop( u'2430', Properties(looptype='',repeat=u'25',pos=u'540',req_sit=u'S',desc=u'Line Adjudication Information'),
Segment( u'SVD', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'540',desc=u'Line Adjudication Information'),
  Element( u'SVD01', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=1,
    codes=[] ) ),
  Element( u'SVD02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Composite( u'C003', Properties(req_sit=u'R',refdes='',seq=u'03',desc=u'Procedure Identifier'),
    Element( u'SVD03-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC', u'IV', u'ZZ'] ) ),
    Element( u'SVD03-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SVD03-03', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SVD03-04', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SVD03-05', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SVD03-06', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SVD03-07', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SVD04', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=4,
    codes=[] ) ),
  Element( u'SVD05', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=5,
    codes=[] ) ),
  Element( u'SVD06', Properties(desc=u'Assigned Number', req_sit=u'S', data_type=(u'N0',u'1',u'6'), position=6,
    codes=[] ) ),
),
Segment( u'CAS', Properties(syntax=u'L050607 C0605 C0705 L080910 C0908 C1008 L111213 C1211 C1311 L141516 C1514 C1614 L171819 C1817 C1917',req_sit=u'S',repeat=u'99',pos=u'545',desc=u'Line Adjustment'),
  Element( u'CAS01', Properties(desc=u'Claim Adjustment Group Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[u'CO', u'CR', u'OA', u'PI', u'PR'] ) ),
  Element( u'CAS02', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'5'), position=2,
    codes=[] ) ),
  Element( u'CAS03', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'CAS04', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'CAS05', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=5,
    codes=[] ) ),
  Element( u'CAS06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'CAS07', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CAS08', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=8,
    codes=[] ) ),
  Element( u'CAS09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'CAS10', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CAS11', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=11,
    codes=[] ) ),
  Element( u'CAS12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'CAS13', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=13,
    codes=[] ) ),
  Element( u'CAS14', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=14,
    codes=[] ) ),
  Element( u'CAS15', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=15,
    codes=[] ) ),
  Element( u'CAS16', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CAS17', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=17,
    codes=[] ) ),
  Element( u'CAS18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'CAS19', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=19,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'550',desc=u'Line Adjudication Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'573'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
)
parsed_837_2440 = Loop( u'2440', Properties(looptype='',repeat=u'5',pos=u'551',req_sit=u'S',desc=u'Form Identification Code'),
Segment( u'LQ', Properties(syntax=u'C0102',req_sit=u'R',repeat=u'1',pos=u'551',desc=u'Form Identification Code'),
  Element( u'LQ01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AS', u'UT'] ) ),
  Element( u'LQ02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=2,
    codes=[] ) ),
),
Segment( u'FRM', Properties(syntax='',req_sit=u'R',repeat=u'99',pos=u'552',desc=u'Supporting Documentation'),
  Element( u'FRM01', Properties(desc=u'Assigned Identification', req_sit=u'R', data_type=(u'AN',u'1',u'20'), position=1,
    codes=[] ) ),
  Element( u'FRM02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'W', u'Y'] ) ),
  Element( u'FRM03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'FRM04', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=4,
    codes=[] ) ),
  Element( u'FRM05', Properties(desc=u'Percent, Decimal Format', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=5,
    codes=[] ) ),
),
)
parsed_837_2400 = Loop( u'2400', Properties(looptype='',repeat=u'50',pos=u'365',req_sit=u'R',desc=u'Service Line'),
Segment( u'LX', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'365',desc=u'Service Line'),
  Element( u'LX01', Properties(desc=u'Assigned Number', req_sit=u'R', data_type=(u'N0',u'1',u'6'), position=1,
    codes=[] ) ),
),
Segment( u'SV1', Properties(syntax=u'P0304',req_sit=u'R',repeat=u'1',pos=u'370',desc=u'Professional Service'),
  Composite( u'C003', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Procedure Identifier'),
    Element( u'SV101-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC', u'IV', u'N4', u'ZZ'] ) ),
    Element( u'SV101-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SV101-03', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SV101-04', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SV101-05', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SV101-06', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SV101-07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SV102', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'SV103', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'F2', u'MJ', u'UN'] ) ),
  Element( u'SV104', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'SV105', Properties(desc=u'Facility Code Value', req_sit=u'S', data_type=(u'AN',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'SV106', Properties(desc=u'Service Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Composite( u'C004', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Diagnosis Code Pointer'),
    Element( u'SV107-01', Properties(desc=u'Diagnosis Code Pointer', req_sit=u'R', data_type=(u'N0',u'1',u'2'), position=0,
      codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
    Element( u'SV107-02', Properties(desc=u'Diagnosis Code Pointer', req_sit=u'S', data_type=(u'N0',u'1',u'2'), position=1,
      codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
    Element( u'SV107-03', Properties(desc=u'Diagnosis Code Pointer', req_sit=u'S', data_type=(u'N0',u'1',u'2'), position=2,
      codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
    Element( u'SV107-04', Properties(desc=u'Diagnosis Code Pointer', req_sit=u'S', data_type=(u'N0',u'1',u'2'), position=3,
      codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
  ),
  Element( u'SV108', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'SV109', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'Y'] ) ),
  Element( u'SV110', Properties(desc=u'Multiple Procedure Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=10,
    codes=[] ) ),
  Element( u'SV111', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=11,
    codes=[u'Y'] ) ),
  Element( u'SV112', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=12,
    codes=[u'Y'] ) ),
  Element( u'SV113', Properties(desc=u'Review Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=13,
    codes=[] ) ),
  Element( u'SV114', Properties(desc=u'National or Local Assigned Review Value', req_sit=u'N', data_type=(u'AN',u'1',u'2'), position=14,
    codes=[] ) ),
  Element( u'SV115', Properties(desc=u'Copay Status Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[u'0'] ) ),
  Element( u'SV116', Properties(desc=u'Health Care Professional Shortage Area Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=16,
    codes=[] ) ),
  Element( u'SV117', Properties(desc=u'Reference Identification', req_sit=u'N', data_type=(u'AN',u'1',u'50'), position=17,
    codes=[] ) ),
  Element( u'SV118', Properties(desc=u'Postal Code', req_sit=u'N', data_type=(u'ID',u'3',u'15'), position=18,
    codes=[] ) ),
  Element( u'SV119', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=19,
    codes=[] ) ),
  Element( u'SV120', Properties(desc=u'Level of Care Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=20,
    codes=[] ) ),
  Element( u'SV121', Properties(desc=u'Provider Agreement Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=21,
    codes=[] ) ),
),
Segment( u'SV5', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'400',desc=u'Durable Medical Equipment Service'),
  Composite( u'C003', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Composite Medical Procedure Identifier'),
    Element( u'SV501-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC'] ) ),
    Element( u'SV501-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SV501-03', Properties(desc=u'Procedure Modifier', req_sit=u'N', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SV501-04', Properties(desc=u'Procedure Modifier', req_sit=u'N', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SV501-05', Properties(desc=u'Procedure Modifier', req_sit=u'N', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SV501-06', Properties(desc=u'Procedure Modifier', req_sit=u'N', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SV501-07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SV502', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'DA'] ) ),
  Element( u'SV503', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=3,
    codes=[] ) ),
  Element( u'SV504', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=4,
    codes=[] ) ),
  Element( u'SV505', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=5,
    codes=[] ) ),
  Element( u'SV506', Properties(desc=u'Frequency Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'1', u'4', u'6'] ) ),
  Element( u'SV507', Properties(desc=u'Prognosis Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[] ) ),
),
Segment( u'PWK', Properties(syntax=u'P0506',req_sit=u'S',repeat=u'1',pos=u'420',desc=u'DMERC CMN Indicator'),
  Element( u'PWK01', Properties(desc=u'Report Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'CT'] ) ),
  Element( u'PWK02', Properties(desc=u'Report Transmission Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[u'AB', u'AD', u'AF', u'AG', u'NS'] ) ),
  Element( u'PWK03', Properties(desc=u'Report Copies Needed', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'PWK04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'PWK05', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'PWK06', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=6,
    codes=[] ) ),
  Element( u'PWK07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=7,
    codes=[] ) ),
  Composite( u'C002', Properties(req_sit=u'N',refdes=u'PWK08',seq=u'08',desc=u'Actions Indicated'),
  ),
  Element( u'PWK09', Properties(desc=u'Request Category Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[] ) ),
),
Segment( u'CR1', Properties(syntax=u'P0102 P0506',req_sit=u'S',repeat=u'1',pos=u'425',desc=u'Ambulance Transport Information'),
  Element( u'CR101', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'LB'] ) ),
  Element( u'CR102', Properties(desc=u'Weight', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=2,
    codes=[] ) ),
  Element( u'CR103', Properties(desc=u'Ambulance Transport Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'I', u'R', u'T', u'X'] ) ),
  Element( u'CR104', Properties(desc=u'Ambulance Transport Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'A', u'B', u'C', u'D', u'E'] ) ),
  Element( u'CR105', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'DH'] ) ),
  Element( u'CR106', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR107', Properties(desc=u'Address Information', req_sit=u'N', data_type=(u'AN',u'1',u'55'), position=7,
    codes=[] ) ),
  Element( u'CR108', Properties(desc=u'Address Information', req_sit=u'N', data_type=(u'AN',u'1',u'55'), position=8,
    codes=[] ) ),
  Element( u'CR109', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=9,
    codes=[] ) ),
  Element( u'CR110', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=10,
    codes=[] ) ),
),
Segment( u'CR2', Properties(syntax=u'P0102 C0403 P0506',req_sit=u'S',repeat=u'5',pos=u'430',desc=u'Spinal Manipulation Service Information'),
  Element( u'CR201', Properties(desc=u'Count', req_sit=u'N', data_type=(u'N0',u'1',u'9'), position=1,
    codes=[] ) ),
  Element( u'CR202', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'CR203', Properties(desc=u'Subluxation Level Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'C1', u'C2', u'C3', u'C4', u'C5', u'C6', u'C7', u'CO', u'IL', u'L1', u'L2', u'L3', u'L4', u'L5', u'OC', u'SA', u'T1', u'T2', u'T3', u'T4', u'T5', u'T6', u'T7', u'T8', u'T9', u'T10', u'T11', u'T12'] ) ),
  Element( u'CR204', Properties(desc=u'Subluxation Level Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'C1', u'C2', u'C3', u'C4', u'C5', u'C6', u'C7', u'CO', u'IL', u'L1', u'L2', u'L3', u'L4', u'L5', u'OC', u'SA', u'T1', u'T2', u'T3', u'T4', u'T5', u'T6', u'T7', u'T8', u'T9', u'T10', u'T11', u'T12'] ) ),
  Element( u'CR205', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'DA', u'MO', u'WK', u'YR'] ) ),
  Element( u'CR206', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR207', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CR208', Properties(desc=u'Nature of Condition Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'A', u'C', u'D', u'E', u'F', u'G', u'M'] ) ),
  Element( u'CR209', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'N', u'Y'] ) ),
  Element( u'CR210', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=10,
    codes=[] ) ),
  Element( u'CR211', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=11,
    codes=[] ) ),
  Element( u'CR212', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=12,
    codes=[u'N', u'Y'] ) ),
),
Segment( u'CR3', Properties(syntax=u'P0203',req_sit=u'S',repeat=u'1',pos=u'435',desc=u'Durable Medical Equipment Certification'),
  Element( u'CR301', Properties(desc=u'Certification Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'I', u'R', u'S'] ) ),
  Element( u'CR302', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'MO'] ) ),
  Element( u'CR303', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=3,
    codes=[] ) ),
  Element( u'CR304', Properties(desc=u'Insulin Dependent Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'CR305', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=5,
    codes=[] ) ),
),
Segment( u'CR5', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'445',desc=u'Home Oxygen Therapy Information'),
  Element( u'CR501', Properties(desc=u'Certification Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'I', u'R', u'S'] ) ),
  Element( u'CR502', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'CR503', Properties(desc=u'Oxygen Equipment Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
  Element( u'CR504', Properties(desc=u'Oxygen Equipment Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'CR505', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=5,
    codes=[] ) ),
  Element( u'CR506', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR507', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CR508', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=8,
    codes=[] ) ),
  Element( u'CR509', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=9,
    codes=[] ) ),
  Element( u'CR510', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CR511', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=11,
    codes=[] ) ),
  Element( u'CR512', Properties(desc=u'Oxygen Test Condition Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=12,
    codes=[u'E', u'R', u'S'] ) ),
  Element( u'CR513', Properties(desc=u'Oxygen Test Findings Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=13,
    codes=[u'1'] ) ),
  Element( u'CR514', Properties(desc=u'Oxygen Test Findings Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=14,
    codes=[u'2'] ) ),
  Element( u'CR515', Properties(desc=u'Oxygen Test Findings Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[u'3'] ) ),
  Element( u'CR516', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CR517', Properties(desc=u'Oxygen Delivery System Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=17,
    codes=[] ) ),
  Element( u'CR518', Properties(desc=u'Oxygen Equipment Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=18,
    codes=[] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'450',desc=u'Ambulance Certification'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'07'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'450',desc=u'Hospice Employee Indicator'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'70'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'65'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'450',desc=u'DMERC Condition Indicator'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'09', u'11'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'37', u'38', u'AL', u'P1', u'ZV'] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'455',desc=u'Date - Service Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'472'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8', u'RD8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Certification Revision Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'607'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Begin Therapy Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'463'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Last Certification Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'461'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Date Last Seen'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'304'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'455',desc=u'Date - Test'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'738', u'739'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'455',desc=u'Date - Oxygen Saturation/Arterial Blood Gas Test'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'119', u'480', u'481'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Shipped'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'011'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Onset of Current Symptom/Illness'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'431'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Last X-ray'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'455'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Acute Manifestation'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'453'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Initial Treatment'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'454'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Date - Similar Illness/Symptom Onset'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'438'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'MEA', Properties(syntax=u'R03050608 C0504 C0604 L07030506 E0803',req_sit=u'S',repeat=u'20',pos=u'462',desc=u'Test Result'),
  Element( u'MEA01', Properties(desc=u'Measurement Reference ID Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'OG', u'TR'] ) ),
  Element( u'MEA02', Properties(desc=u'Measurement Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=2,
    codes=[u'GRA', u'HT', u'R1', u'R2', u'R3', u'R4', u'ZO'] ) ),
  Element( u'MEA03', Properties(desc=u'Measurement Value', req_sit=u'R', data_type=(u'R',u'1',u'20'), position=3,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'N',refdes=u'MEA04',seq=u'04',desc=u'Composite Unit of Measure'),
  ),
  Element( u'MEA05', Properties(desc=u'Range Minimum', req_sit=u'N', data_type=(u'R',u'1',u'20'), position=5,
    codes=[] ) ),
  Element( u'MEA06', Properties(desc=u'Range Maximum', req_sit=u'N', data_type=(u'R',u'1',u'20'), position=6,
    codes=[] ) ),
  Element( u'MEA07', Properties(desc=u'Measurement Significance Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[] ) ),
  Element( u'MEA08', Properties(desc=u'Measurement Attribute Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[] ) ),
  Element( u'MEA09', Properties(desc=u'Surface/Layer/Position Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[] ) ),
  Element( u'MEA10', Properties(desc=u'Measurement Method or Device', req_sit=u'N', data_type=(u'ID',u'2',u'4'), position=10,
    codes=[] ) ),
),
Segment( u'CN1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'465',desc=u'Contract Information'),
  Element( u'CN101', Properties(desc=u'Contract Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'09'] ) ),
  Element( u'CN102', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CN103', Properties(desc=u'Percent, Decimal Format', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=3,
    codes=[] ) ),
  Element( u'CN104', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'CN105', Properties(desc=u'Terms Discount Percent', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=5,
    codes=[] ) ),
  Element( u'CN106', Properties(desc=u'Version Identifier', req_sit=u'S', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Repriced Line Item Reference Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9B'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Adjusted Repriced Line Item Reference Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9D'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'470',desc=u'Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'4',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Line Item Control Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'6R'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Mammography Certification Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'EW'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Clinical Laboratory Improvement Amendment (CLIA) Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'X4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Referring Clinical Laboratory Improvement Amendment (CLIA) Facility Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'F4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Immunization Batch Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'BT'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'4',pos=u'470',desc=u'Ambulatory Patient Group (APG)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1S'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Oxygen Flow Rate'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'TP'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'470',desc=u'Universal Product Number (UPN)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'OZ', u'VP'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Sales Tax Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'T'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Approved Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AAE'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Postage Claimed Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F4'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'K3', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'480',desc=u'File Information'),
  Element( u'K301', Properties(desc=u'Fixed Format Information', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=1,
    codes=[] ) ),
  Element( u'K302', Properties(desc=u'Record Format Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'N',refdes=u'K303',seq=u'03',desc=u'Composite Unit of Measure'),
  ),
),
Segment( u'NTE', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'485',desc=u'Line Note'),
  Element( u'NTE01', Properties(desc=u'Note Reference Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'ADD', u'DCP', u'PMT', u'TPO'] ) ),
  Element( u'NTE02', Properties(desc=u'Description', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=2,
    codes=[] ) ),
),
Segment( u'PS1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'488',desc=u'Purchased Service Information'),
  Element( u'PS101', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=1,
    codes=[] ) ),
  Element( u'PS102', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'PS103', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[] ) ),
),
Segment( u'HSD', Properties(syntax=u'P0102 C0605',req_sit=u'S',repeat=u'1',pos=u'491',desc=u'Health Care Services Delivery'),
  Element( u'HSD01', Properties(desc=u'Quantity Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'VS'] ) ),
  Element( u'HSD02', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'HSD03', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'DA', u'MO', u'Q1', u'WK'] ) ),
  Element( u'HSD04', Properties(desc=u'Sample Selection Modulus', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=4,
    codes=[] ) ),
  Element( u'HSD05', Properties(desc=u'Time Period Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'7', u'34', u'35'] ) ),
  Element( u'HSD06', Properties(desc=u'Number of Periods', req_sit=u'S', data_type=(u'N0',u'1',u'3'), position=6,
    codes=[] ) ),
  Element( u'HSD07', Properties(desc=u'Ship/Delivery or Calendar Pattern Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=7,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'J', u'K', u'L', u'N', u'O', u'W', u'SA', u'SB', u'SC', u'SD', u'SG', u'SL', u'SP', u'SX', u'SY', u'SZ'] ) ),
  Element( u'HSD08', Properties(desc=u'Ship/Delivery Pattern Time Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'D', u'E', u'F'] ) ),
),
Segment( u'HCP', Properties(syntax=u'R0113 P0910 P1112',req_sit=u'S',repeat=u'1',pos=u'492',desc=u'Line Pricing/Repricing Information'),
  Element( u'HCP01', Properties(desc=u'Pricing Methodology', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'10', u'11', u'12', u'13', u'14'] ) ),
  Element( u'HCP02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'HCP03', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'HCP04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'HCP05', Properties(desc=u'Rate', req_sit=u'S', data_type=(u'R',u'1',u'9'), position=5,
    codes=[] ) ),
  Element( u'HCP06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'HCP07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'HCP08', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=8,
    codes=[] ) ),
  Element( u'HCP09', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[u'HC', u'IV', u'ZZ'] ) ),
  Element( u'HCP10', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=10,
    codes=[] ) ),
  Element( u'HCP11', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=11,
    codes=[u'DA', u'UN'] ) ),
  Element( u'HCP12', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=12,
    codes=[] ) ),
  Element( u'HCP13', Properties(desc=u'Reject Reason Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=13,
    codes=[u'T1', u'T2', u'T3', u'T4', u'T5', u'T6'] ) ),
  Element( u'HCP14', Properties(desc=u'Policy Compliance Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5'] ) ),
  Element( u'HCP15', Properties(desc=u'Exception Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=15,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6'] ) ),
),
parsed_837_2410,
parsed_837_2420A,
parsed_837_2420B,
parsed_837_2420C,
parsed_837_2420D,
parsed_837_2420E,
parsed_837_2420F,
parsed_837_2420G,
parsed_837_2430,
parsed_837_2440,
)
parsed_837_2300 = Loop( u'2300', Properties(looptype='',repeat=u'100',pos=u'130',req_sit=u'S',desc=u'Claim Information'),
Segment( u'CLM', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'130',desc=u'Claim Information'),
  Element( u'CLM01', Properties(desc=u"Claim Submitter's Identifier", req_sit=u'R', data_type=(u'AN',u'1',u'38'), position=1,
    codes=[] ) ),
  Element( u'CLM02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CLM03', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'CLM04', Properties(desc=u'Non-Institutional Claim Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C023', Properties(req_sit=u'R',refdes='',seq=u'05',desc=u'Place of Service Code'),
    Element( u'CLM05-01', Properties(desc=u'Facility Code Value', req_sit=u'R', data_type=(u'AN',u'1',u'2'), position=0,
      codes=[] ) ),
    Element( u'CLM05-02', Properties(desc=u'Facility Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=1,
      codes=[] ) ),
    Element( u'CLM05-03', Properties(desc=u'Claim Frequency Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
      codes=[] ) ),
  ),
  Element( u'CLM06', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM07', Properties(desc=u'Provider Accept Assignment Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[u'A', u'B', u'C', u'P'] ) ),
  Element( u'CLM08', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM09', Properties(desc=u'Release of Information Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'A', u'I', u'M', u'N', u'O', u'Y'] ) ),
  Element( u'CLM10', Properties(desc=u'Patient Signature Source Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=10,
    codes=[u'B', u'C', u'M', u'P', u'S'] ) ),
  Composite( u'C024', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Accident/Employment/Related Causes'),
    Element( u'CLM11-01', Properties(desc=u'Related-Causes Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=0,
      codes=[u'AA', u'AP', u'EM', u'OA'] ) ),
    Element( u'CLM11-02', Properties(desc=u'Related-Causes Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=1,
      codes=[u'AA', u'AP', u'EM', u'OA'] ) ),
    Element( u'CLM11-03', Properties(desc=u'Related-Causes Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'AA', u'AP', u'EM', u'OA'] ) ),
    Element( u'CLM11-04', Properties(desc=u'State or Province Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'CLM11-05', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
      codes=[] ) ),
  ),
  Element( u'CLM12', Properties(desc=u'Special Program Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=12,
    codes=[u'01', u'02', u'03', u'05', u'07', u'08', u'09'] ) ),
  Element( u'CLM13', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=13,
    codes=[] ) ),
  Element( u'CLM14', Properties(desc=u'Level of Service Code', req_sit=u'N', data_type=(u'ID',u'1',u'3'), position=14,
    codes=[] ) ),
  Element( u'CLM15', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[] ) ),
  Element( u'CLM16', Properties(desc=u'Provider Agreement Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=16,
    codes=[u'P'] ) ),
  Element( u'CLM17', Properties(desc=u'Claim Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=17,
    codes=[] ) ),
  Element( u'CLM18', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=18,
    codes=[] ) ),
  Element( u'CLM19', Properties(desc=u'Claim Submission Reason Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=19,
    codes=[] ) ),
  Element( u'CLM20', Properties(desc=u'Delay Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=20,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11'] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Initial Treatment'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'454'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Date Last Seen'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'304'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Onset of Current Illness/Symptom'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'431'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'135',desc=u'Date - Acute Manifestation'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'453'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'135',desc=u'Date - Similar Illness/Symptom Onset'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'438'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'135',desc=u'Date - Accident'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'439'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8', u'DT'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Last Menstrual Period'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'484'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Last X-Ray'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'455'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Hearing and Vision Prescription Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'471'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'135',desc=u'Date - Disability Begin'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'360'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'135',desc=u'Date - Disability End'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'361'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Last Worked'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'297'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Authorized Return to Work'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'296'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Admission'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'435'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Date - Discharge'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'096'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'135',desc=u'Date - Assumed and Relinquished Care Dates'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'090', u'091'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'PWK', Properties(syntax=u'P0506',req_sit=u'S',repeat=u'10',pos=u'155',desc=u'Claim Supplemental Information'),
  Element( u'PWK01', Properties(desc=u'Report Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'77', u'AS', u'B2', u'B3', u'B4', u'CT', u'DA', u'DG', u'DS', u'EB', u'MT', u'NN', u'OB', u'OZ', u'PN', u'PO', u'PZ', u'RB', u'RR', u'RT'] ) ),
  Element( u'PWK02', Properties(desc=u'Report Transmission Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[u'AA', u'BM', u'EL', u'EM', u'FX'] ) ),
  Element( u'PWK03', Properties(desc=u'Report Copies Needed', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'PWK04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'PWK05', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'AC'] ) ),
  Element( u'PWK06', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=6,
    codes=[] ) ),
  Element( u'PWK07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=7,
    codes=[] ) ),
  Composite( u'C002', Properties(req_sit=u'N',refdes=u'PWK08',seq=u'08',desc=u'Actions Indicated'),
  ),
  Element( u'PWK09', Properties(desc=u'Request Category Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[] ) ),
),
Segment( u'CN1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'160',desc=u'Contract Information'),
  Element( u'CN101', Properties(desc=u'Contract Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'02', u'03', u'04', u'05', u'06', u'09'] ) ),
  Element( u'CN102', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CN103', Properties(desc=u'Percent, Decimal Format', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=3,
    codes=[] ) ),
  Element( u'CN104', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'CN105', Properties(desc=u'Terms Discount Percent', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=5,
    codes=[] ) ),
  Element( u'CN106', Properties(desc=u'Version Identifier', req_sit=u'S', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Credit/Debit Card Maximum Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'MA'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Patient Amount Paid'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F5'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Total Purchased Service Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'NE'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Service Authorization Exception Code'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'4N'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Mandatory Medicare (Section 4081) Crossover Indicator'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'F5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'Y', u'N'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Mammography Certification Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'EW'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'2',pos=u'180',desc=u'Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Original Reference Number (ICN/DCN)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'F8'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'3',pos=u'180',desc=u'Clinical Laboratory Improvement Amendment (CLIA) Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'X4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Repriced Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9A'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Adjusted Repriced Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9C'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Investigational Device Exemption Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'LX'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Claim Identification Number for Clearing Houses and Other Transmission Intermediaries'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D9'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'4',pos=u'180',desc=u'Ambulatory Patient Group (APG)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1S'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Medical Record Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'EA'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax=u'R0203',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Demonstration Project Identifier'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'P4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes=u'REF04',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'K3', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'185',desc=u'File Information'),
  Element( u'K301', Properties(desc=u'Fixed Format Information', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=1,
    codes=[] ) ),
  Element( u'K302', Properties(desc=u'Record Format Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'N',refdes=u'K303',seq=u'03',desc=u'Composite Unit of Measure'),
  ),
),
Segment( u'NTE', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'190',desc=u'Claim Note'),
  Element( u'NTE01', Properties(desc=u'Note Reference Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'ADD', u'CER', u'DCP', u'DGN', u'PMT', u'TPO'] ) ),
  Element( u'NTE02', Properties(desc=u'Description', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=2,
    codes=[] ) ),
),
Segment( u'CR1', Properties(syntax=u'P0102 P0506',req_sit=u'S',repeat=u'1',pos=u'195',desc=u'Ambulance Transport Information'),
  Element( u'CR101', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'LB'] ) ),
  Element( u'CR102', Properties(desc=u'Weight', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=2,
    codes=[] ) ),
  Element( u'CR103', Properties(desc=u'Ambulance Transport Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'I', u'R', u'T', u'X'] ) ),
  Element( u'CR104', Properties(desc=u'Ambulance Transport Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'A', u'B', u'C', u'D', u'E'] ) ),
  Element( u'CR105', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'DH'] ) ),
  Element( u'CR106', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR107', Properties(desc=u'Address Information', req_sit=u'N', data_type=(u'AN',u'1',u'55'), position=7,
    codes=[] ) ),
  Element( u'CR108', Properties(desc=u'Address Information', req_sit=u'N', data_type=(u'AN',u'1',u'55'), position=8,
    codes=[] ) ),
  Element( u'CR109', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=9,
    codes=[] ) ),
  Element( u'CR110', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=10,
    codes=[] ) ),
),
Segment( u'CR2', Properties(syntax=u'P0102 C0403 P0506',req_sit=u'S',repeat=u'1',pos=u'200',desc=u'Spinal Manipulation Service Information'),
  Element( u'CR201', Properties(desc=u'Count', req_sit=u'N', data_type=(u'N0',u'1',u'9'), position=1,
    codes=[] ) ),
  Element( u'CR202', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'CR203', Properties(desc=u'Subluxation Level Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'C1', u'C2', u'C3', u'C4', u'C5', u'C6', u'C7', u'CO', u'IL', u'L1', u'L2', u'L3', u'L4', u'L5', u'OC', u'SA', u'T1', u'T2', u'T3', u'T4', u'T5', u'T6', u'T7', u'T8', u'T9', u'T10', u'T11', u'T12'] ) ),
  Element( u'CR204', Properties(desc=u'Subluxation Level Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'C1', u'C2', u'C3', u'C4', u'C5', u'C6', u'C7', u'CO', u'IL', u'L1', u'L2', u'L3', u'L4', u'L5', u'OC', u'SA', u'T1', u'T2', u'T3', u'T4', u'T5', u'T6', u'T7', u'T8', u'T9', u'T10', u'T11', u'T12'] ) ),
  Element( u'CR205', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'DA', u'MO', u'WK', u'YR'] ) ),
  Element( u'CR206', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=6,
    codes=[] ) ),
  Element( u'CR207', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CR208', Properties(desc=u'Nature of Condition Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'A', u'C', u'D', u'E', u'F', u'G', u'M'] ) ),
  Element( u'CR209', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'N', u'Y'] ) ),
  Element( u'CR210', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=10,
    codes=[] ) ),
  Element( u'CR211', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=11,
    codes=[] ) ),
  Element( u'CR212', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=12,
    codes=[u'N', u'Y'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'220',desc=u'Ambulance Certification'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'07'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'60'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'220',desc=u'Patient Condition Information:  Vision'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'E1', u'E2', u'E3'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'L1', u'L2', u'L3', u'L4', u'L5'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'220',desc=u'Homebound Indicator'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'75'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'IH'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'220',desc=u'EPSDT Referral'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'ZZ'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'AV', u'NU', u'S2', u'ST'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'AV', u'NU', u'S2', u'ST'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'AV', u'NU', u'S2', u'ST'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'231',desc=u'Health Care Diagnosis Code'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Principal Diagnosis'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BK'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Diagnosis'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Diagnosis'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Diagnosis'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Diagnosis'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Diagnosis'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Diagnosis'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Diagnosis'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes=u'HI09',seq=u'09',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes=u'HI10',seq=u'10',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes=u'HI11',seq=u'11',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes=u'HI12',seq=u'12',desc=u'Health Care Code Information'),
  ),
),
Segment( u'HCP', Properties(syntax=u'R0113 P0910 P1112',req_sit=u'S',repeat=u'1',pos=u'241',desc=u'Claim Pricing/Repricing Information'),
  Element( u'HCP01', Properties(desc=u'Pricing Methodology', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'01', u'02', u'03', u'04', u'05', u'07', u'08', u'09', u'10', u'11', u'12', u'13', u'14'] ) ),
  Element( u'HCP02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'HCP03', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'HCP04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'HCP05', Properties(desc=u'Rate', req_sit=u'S', data_type=(u'R',u'1',u'9'), position=5,
    codes=[] ) ),
  Element( u'HCP06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'HCP07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'HCP08', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=8,
    codes=[] ) ),
  Element( u'HCP09', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[] ) ),
  Element( u'HCP10', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=10,
    codes=[] ) ),
  Element( u'HCP11', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=11,
    codes=[] ) ),
  Element( u'HCP12', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=12,
    codes=[] ) ),
  Element( u'HCP13', Properties(desc=u'Reject Reason Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=13,
    codes=[u'T1', u'T2', u'T3', u'T4', u'T5', u'T6'] ) ),
  Element( u'HCP14', Properties(desc=u'Policy Compliance Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5'] ) ),
  Element( u'HCP15', Properties(desc=u'Exception Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=15,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6'] ) ),
),
parsed_837_2305,
parsed_837_2310A,
parsed_837_2310B,
parsed_837_2310C,
parsed_837_2310D,
parsed_837_2310E,
parsed_837_2320,
parsed_837_2400,
)
parsed_837_2000C = Loop( u'2000C', Properties(looptype='',repeat=u'>1',pos=u'140',req_sit=u'S',desc=u'Patient Hierarchical Level'),
Segment( u'HL', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'001',desc=u'Patient Hierarchical Level'),
  Element( u'HL01', Properties(desc=u'Hierarchical ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=1,
    codes=[] ) ),
  Element( u'HL02', Properties(desc=u'Hierarchical Parent ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=2,
    codes=[] ) ),
  Element( u'HL03', Properties(desc=u'Hierarchical Level Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[u'23'] ) ),
  Element( u'HL04', Properties(desc=u'Hierarchical Child Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'0'] ) ),
),
Segment( u'PAT', Properties(syntax=u'P0506 P0708',req_sit=u'R',repeat=u'1',pos=u'007',desc=u'Patient Information'),
  Element( u'PAT01', Properties(desc=u'Individual Relationship Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'01', u'04', u'05', u'07', u'09', u'10', u'15', u'17', u'19', u'20', u'21', u'22', u'23', u'24', u'29', u'32', u'33', u'34', u'36', u'39', u'40', u'41', u'43', u'53', u'G8'] ) ),
  Element( u'PAT02', Properties(desc=u'Patient Location Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[] ) ),
  Element( u'PAT03', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[] ) ),
  Element( u'PAT04', Properties(desc=u'Student Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'PAT05', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'D8'] ) ),
  Element( u'PAT06', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=6,
    codes=[] ) ),
  Element( u'PAT07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'01'] ) ),
  Element( u'PAT08', Properties(desc=u'Weight', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=8,
    codes=[] ) ),
  Element( u'PAT09', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'Y'] ) ),
),
parsed_837_2010CA,
parsed_837_2300,
)
parsed_837_2000B = Loop( u'2000B', Properties(looptype='',repeat=u'>1',pos=u'020',req_sit=u'R',desc=u'Subscriber Hierarchical Level'),
Segment( u'HL', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'001',desc=u'Subscriber Hierarchical Level'),
  Element( u'HL01', Properties(desc=u'Hierarchical ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=1,
    codes=[] ) ),
  Element( u'HL02', Properties(desc=u'Hierarchical Parent ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=2,
    codes=[] ) ),
  Element( u'HL03', Properties(desc=u'Hierarchical Level Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[u'22'] ) ),
  Element( u'HL04', Properties(desc=u'Hierarchical Child Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'0', u'1'] ) ),
),
Segment( u'SBR', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'005',desc=u'Subscriber Information'),
  Element( u'SBR01', Properties(desc=u'Payer Responsibility Sequence Number Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'P', u'S', u'T'] ) ),
  Element( u'SBR02', Properties(desc=u'Individual Relationship Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'18'] ) ),
  Element( u'SBR03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'SBR04', Properties(desc=u'Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=4,
    codes=[] ) ),
  Element( u'SBR05', Properties(desc=u'Insurance Type Code', req_sit=u'S', data_type=(u'ID',u'1',u'3'), position=5,
    codes=[u'12', u'13', u'14', u'15', u'16', u'41', u'42', u'43', u'47'] ) ),
  Element( u'SBR06', Properties(desc=u'Coordination of Benefits Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[] ) ),
  Element( u'SBR07', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[] ) ),
  Element( u'SBR08', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[] ) ),
  Element( u'SBR09', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[u'09', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'AM', u'BL', u'CH', u'CI', u'DS', u'HM', u'LI', u'LM', u'MB', u'MC', u'OF', u'TV', u'VA', u'WC', u'ZZ'] ) ),
),
Segment( u'PAT', Properties(syntax=u'P0506 P0708',req_sit=u'S',repeat=u'1',pos=u'007',desc=u'Patient Information'),
  Element( u'PAT01', Properties(desc=u'Individual Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[] ) ),
  Element( u'PAT02', Properties(desc=u'Patient Location Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[] ) ),
  Element( u'PAT03', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[] ) ),
  Element( u'PAT04', Properties(desc=u'Student Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'PAT05', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'D8'] ) ),
  Element( u'PAT06', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=6,
    codes=[] ) ),
  Element( u'PAT07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'01'] ) ),
  Element( u'PAT08', Properties(desc=u'Weight', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=8,
    codes=[] ) ),
  Element( u'PAT09', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'Y'] ) ),
),
parsed_837_2010BA,
parsed_837_2010BB,
parsed_837_2010BC,
parsed_837_2010BD,
parsed_837_2300,
parsed_837_2000C,
)
parsed_837_2000A = Loop( u'2000A', Properties(looptype='',repeat=u'>1',pos=u'001',req_sit=u'R',desc=u'Billing/Pay-To Provider Hierarchical Level'),
Segment( u'HL', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'001',desc=u'Billing/Pay-To Provider Hierarchical Level'),
  Element( u'HL01', Properties(desc=u'Hierarchical ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=1,
    codes=[] ) ),
  Element( u'HL02', Properties(desc=u'Hierarchical Parent ID Number', req_sit=u'N', data_type=(u'AN',u'1',u'12'), position=2,
    codes=[] ) ),
  Element( u'HL03', Properties(desc=u'Hierarchical Level Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[u'20'] ) ),
  Element( u'HL04', Properties(desc=u'Hierarchical Child Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'1'] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'003',desc=u'Billing/Pay-To Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'BI', u'PT'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'CUR', Properties(syntax=u'C0807 C0907 L101112 C1110 C1210 L131415 C1413 C1513 L161718 C1716 C1816 L192021 C2019 C2119',req_sit=u'S',repeat=u'1',pos=u'010',desc=u'Foreign Currency Information'),
  Element( u'CUR01', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'85'] ) ),
  Element( u'CUR02', Properties(desc=u'Currency Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=2,
    codes=[] ) ),
  Element( u'CUR03', Properties(desc=u'Exchange Rate', req_sit=u'N', data_type=(u'R',u'4',u'10'), position=3,
    codes=[] ) ),
  Element( u'CUR04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'CUR05', Properties(desc=u'Currency Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=5,
    codes=[] ) ),
  Element( u'CUR06', Properties(desc=u'Currency Market/Exchange Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
  Element( u'CUR07', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=7,
    codes=[] ) ),
  Element( u'CUR08', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=8,
    codes=[] ) ),
  Element( u'CUR09', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=9,
    codes=[] ) ),
  Element( u'CUR10', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=10,
    codes=[] ) ),
  Element( u'CUR11', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=11,
    codes=[] ) ),
  Element( u'CUR12', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=12,
    codes=[] ) ),
  Element( u'CUR13', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=13,
    codes=[] ) ),
  Element( u'CUR14', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=14,
    codes=[] ) ),
  Element( u'CUR15', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=15,
    codes=[] ) ),
  Element( u'CUR16', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=16,
    codes=[] ) ),
  Element( u'CUR17', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=17,
    codes=[] ) ),
  Element( u'CUR18', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=18,
    codes=[] ) ),
  Element( u'CUR19', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=19,
    codes=[] ) ),
  Element( u'CUR20', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=20,
    codes=[] ) ),
  Element( u'CUR21', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=21,
    codes=[] ) ),
),
parsed_837_2010AA,
parsed_837_2010AB,
parsed_837_2000B,
)
parsed_837_DETAIL = Loop( u'DETAIL', Properties(looptype=u'wrapper',repeat=u'>1',pos=u'020',req_sit=u'S',desc=u'Table 2 - Detail'),
parsed_837_2000A,
)
parsed_837_ST_LOOP = Loop( u'ST_LOOP', Properties(looptype=u'explicit',repeat=u'>1',pos=u'020',req_sit=u'R',desc=u'Transaction Set Header'),
Segment( u'ST', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'005',desc=u'Transaction Set Header'),
  Element( u'ST01', Properties(desc=u'Transaction Set Identifier Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'837'] ) ),
  Element( u'ST02', Properties(desc=u'Transaction Set Control Number', req_sit=u'R', data_type=(u'AN',u'4',u'9'), position=2,
    codes=[] ) ),
),
parsed_837_HEADER,
parsed_837_DETAIL,
Segment( u'SE', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'555',desc=u'Transaction Set Trailer'),
  Element( u'SE01', Properties(desc=u'Number of Included Segments', req_sit=u'R', data_type=(u'N0',u'1',u'10'), position=1,
    codes=[] ) ),
  Element( u'SE02', Properties(desc=u'Transaction Set Control Number', req_sit=u'R', data_type=(u'AN',u'4',u'9'), position=2,
    codes=[] ) ),
),
)
parsed_837_GS_LOOP = Loop( u'GS_LOOP', Properties(looptype=u'explicit',repeat=u'>1',pos=u'020',req_sit=u'R',desc=u'Functional Group Header'),
Segment( u'GS', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'010',desc=u'Functional Group Header'),
  Element( u'GS01', Properties(desc=u'Functional Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'HC'] ) ),
  Element( u'GS02', Properties(desc=u'Application Senders Code', req_sit=u'R', data_type=(u'AN',u'2',u'15'), position=2,
    codes=[] ) ),
  Element( u'GS03', Properties(desc=u'124', req_sit=u'R', data_type=(u'AN',u'2',u'15'), position=3,
    codes=[] ) ),
  Element( u'GS04', Properties(desc=u'Date', req_sit=u'R', data_type=(u'DT',u'8',u'8'), position=4,
    codes=[] ) ),
  Element( u'GS05', Properties(desc=u'Time', req_sit=u'R', data_type=(u'TM',u'4',u'8'), position=5,
    codes=[] ) ),
  Element( u'GS06', Properties(desc=u'Group Control Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=6,
    codes=[] ) ),
  Element( u'GS07', Properties(desc=u'Responsible Agency Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=7,
    codes=[u'X'] ) ),
  Element( u'GS08', Properties(desc=u'Version / Release / Industry Identifier Code', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=8,
    codes=[u'004010X098A1'] ) ),
),
parsed_837_ST_LOOP,
Segment( u'GE', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Functional Group Trailer'),
  Element( u'GE01', Properties(desc=u'97', req_sit=u'R', data_type=(u'N0',u'1',u'6'), position=1,
    codes=[] ) ),
  Element( u'GE02', Properties(desc=u'Group Control Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=2,
    codes=[] ) ),
),
)
parsed_837_ISA_LOOP = Loop( u'ISA_LOOP', Properties(looptype=u'explicit',repeat=u'>1',pos=u'001',req_sit=u'R',desc=u'Interchange Control Header'),
Segment( u'ISA', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'010',desc=u'Interchange Control Header'),
  Element( u'ISA01', Properties(desc=u'I01', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'03'] ) ),
  Element( u'ISA02', Properties(desc=u'I02', req_sit=u'R', data_type=(u'AN',u'10',u'10'), position=2,
    codes=[] ) ),
  Element( u'ISA03', Properties(desc=u'I03', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'00', u'01'] ) ),
  Element( u'ISA04', Properties(desc=u'I04', req_sit=u'R', data_type=(u'AN',u'10',u'10'), position=4,
    codes=[] ) ),
  Element( u'ISA05', Properties(desc=u'I05', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'01', u'14', u'20', u'27', u'28', u'29', u'30', u'33', u'ZZ'] ) ),
  Element( u'ISA06', Properties(desc=u'I06', req_sit=u'R', data_type=(u'AN',u'15',u'15'), position=6,
    codes=[] ) ),
  Element( u'ISA07', Properties(desc=u'I05', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'01', u'14', u'20', u'27', u'28', u'29', u'30', u'33', u'ZZ'] ) ),
  Element( u'ISA08', Properties(desc=u'I07', req_sit=u'R', data_type=(u'AN',u'15',u'15'), position=8,
    codes=[] ) ),
  Element( u'ISA09', Properties(desc=u'I08', req_sit=u'R', data_type=(u'DT',u'6',u'6'), position=9,
    codes=[] ) ),
  Element( u'ISA10', Properties(desc=u'I09', req_sit=u'R', data_type=(u'TM',u'4',u'4'), position=10,
    codes=[] ) ),
  Element( u'ISA11', Properties(desc=u'I10', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=11,
    codes=[u'U'] ) ),
  Element( u'ISA12', Properties(desc=u'I11', req_sit=u'R', data_type=(u'ID',u'5',u'5'), position=12,
    codes=[u'00401'] ) ),
  Element( u'ISA13', Properties(desc=u'I12', req_sit=u'R', data_type=(u'N0',u'9',u'9'), position=13,
    codes=[] ) ),
  Element( u'ISA14', Properties(desc=u'I13', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=14,
    codes=[u'0', u'1'] ) ),
  Element( u'ISA15', Properties(desc=u'I14', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[u'P', u'T'] ) ),
  Element( u'ISA16', Properties(desc=u'I15', req_sit=u'R', data_type=(u'AN',u'1',u'1'), position=16,
    codes=[] ) ),
),
parsed_837_GS_LOOP,
Segment( u'TA1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'020',desc=u'Interchange Acknowledgement'),
  Element( u'TA101', Properties(desc=u'I12', req_sit=u'R', data_type=(u'N0',u'9',u'9'), position=1,
    codes=[] ) ),
  Element( u'TA102', Properties(desc=u'I08', req_sit=u'R', data_type=(u'DT',u'6',u'6'), position=2,
    codes=[] ) ),
  Element( u'TA103', Properties(desc=u'I09', req_sit=u'R', data_type=(u'TM',u'4',u'4'), position=3,
    codes=[] ) ),
  Element( u'TA104', Properties(desc=u'I17', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'A', u'E', u'R'] ) ),
  Element( u'TA105', Properties(desc=u'I18', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=5,
    codes=[u'000', u'001', u'002', u'003', u'004', u'005', u'006', u'007', u'008', u'009', u'010', u'011', u'012', u'013', u'014', u'015', u'016', u'017', u'018', u'019', u'020', u'021', u'022', u'023', u'024', u'025', u'026', u'027', u'028', u'029', u'030', u'031'] ) ),
),
Segment( u'IEA', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Interchange Control Trailer'),
  Element( u'IEA01', Properties(desc=u'I16', req_sit=u'R', data_type=(u'N0',u'1',u'5'), position=1,
    codes=[] ) ),
  Element( u'IEA02', Properties(desc=u'I12', req_sit=u'R', data_type=(u'N0',u'9',u'9'), position=2,
    codes=[] ) ),
),
)
parsed_837 = Message( u'837', Properties(desc=u'HIPAA Health Care Claim: Professional X098A1-837'),
parsed_837_ISA_LOOP,
)

